@@ -144,32 +144,35 @@ def load_module(env, middleware_factory, name):
 
     if name == "booth":
         bindings = {
-            "config_setup": booth.config_setup,
             "config_destroy": booth.config_destroy,
+            "config_setup": booth.config_setup,
+            "config_sync": booth.config_sync,
             "config_text": booth.config_text,
             "config_ticket_add": booth.config_ticket_add,
             "config_ticket_remove": booth.config_ticket_remove,
             "create_in_cluster": booth.create_in_cluster,
+            "disable_booth": booth.disable_booth,
+            "enable_booth": booth.enable_booth,
+            "get_status": booth.get_status,
+            "pull_config": booth.pull_config,
             "remove_from_cluster": booth.remove_from_cluster,
             "restart": booth.restart,
-            "config_sync": booth.config_sync,
-            "enable_booth": booth.enable_booth,
-            "disable_booth": booth.disable_booth,
             "start_booth": booth.start_booth,
             "stop_booth": booth.stop_booth,
-            "pull_config": booth.pull_config,
-            "get_status": booth.get_status,
+            "ticket_cleanup": booth.ticket_cleanup,
             "ticket_grant": booth.ticket_grant,
             "ticket_revoke": booth.ticket_revoke,
+            "ticket_standby": booth.ticket_standby,
+            "ticket_unstandby": booth.ticket_unstandby,
         }
         if settings.booth_enable_authfile_set_enabled:
-            bindings[
-                "config_set_enable_authfile"
-            ] = booth.config_set_enable_authfile
+            bindings["config_set_enable_authfile"] = (
+                booth.config_set_enable_authfile
+            )
         if settings.booth_enable_authfile_unset_enabled:
-            bindings[
-                "config_unset_enable_authfile"
-            ] = booth.config_unset_enable_authfile
+            bindings["config_unset_enable_authfile"] = (
+                booth.config_unset_enable_authfile
+            )
         return bind_all(
             env,
             middleware.build(
@@ -208,6 +211,7 @@ def load_module(env, middleware_factory, name):
                 "verify": cluster.verify,
                 "generate_cluster_uuid": cluster.generate_cluster_uuid,
                 "generate_cluster_uuid_local": cluster.generate_cluster_uuid_local,
+                "wait_for_pcmk_idle": cluster.wait_for_pcmk_idle,
             },
         )
 
@@ -283,6 +287,7 @@ def load_module(env, middleware_factory, name):
             {
                 "add_level": fencing_topology.add_level,
                 "get_config": fencing_topology.get_config,
+                "get_config_dto": fencing_topology.get_config_dto,
                 "remove_all_levels": fencing_topology.remove_all_levels,
                 "remove_levels_by_params": (
                     fencing_topology.remove_levels_by_params
@@ -404,15 +409,16 @@ def load_module(env, middleware_factory, name):
                 "enable": resource.enable,
                 "get_configured_resources": resource.get_configured_resources,
                 "get_failcounts": resource.get_failcounts,
+                "get_resource_relations_tree": (
+                    resource.get_resource_relations_tree
+                ),
                 "group_add": resource.group_add,
                 "is_any_resource_except_stonith": resource.is_any_resource_except_stonith,
                 "is_any_stonith": resource.is_any_stonith,
                 "manage": resource.manage,
                 "move": resource.move,
                 "move_autoclean": resource.move_autoclean,
-                "get_resource_relations_tree": (
-                    resource.get_resource_relations_tree
-                ),
+                "restart": resource.restart,
                 "unmanage": resource.unmanage,
                 "unmove_unban": resource.unmove_unban,
             },
@@ -448,6 +454,7 @@ def load_module(env, middleware_factory, name):
                 "full_cluster_status_plaintext": (
                     status.full_cluster_status_plaintext
                 ),
+                "resources_status": status.resources_status,
             },
         )
 
@@ -528,6 +535,7 @@ def load_module(env, middleware_factory, name):
             {
                 "config": tag.config,
                 "create": tag.create,
+                "get_config_dto": tag.get_config_dto,
                 "remove": tag.remove,
                 "update": tag.update,
             },
