@@ -114,6 +114,8 @@ PCS_LONG_OPTIONS: Final = [
     "token=",
     # enable agent self validation
     "agent-validation",
+    # disable text output in query commands
+    "quiet",
 ]
 
 
@@ -532,6 +534,7 @@ class InputModifiers:
                 "--expired": "--expired" in options,
                 "--force": "--force" in options,
                 "--full": "--full" in options,
+                "--quiet": "--quiet" in options,
                 FUTURE_OPTION: FUTURE_OPTION in options,
                 # TODO remove
                 # used only in deprecated 'pcs resource|stonith show'
@@ -611,11 +614,13 @@ class InputModifiers:
                     option_list=format_list(sorted(unsupported_options)),
                     _is=pluralize("is"),
                 ),
-                hint="Syntax has changed from previous version. {}".format(
-                    SEE_MAN_CHANGES.format("0.11")
-                )
-                if hint_syntax_changed
-                else None,
+                hint=(
+                    "Syntax has changed from previous version. {}".format(
+                        SEE_MAN_CHANGES.format("0.11")
+                    )
+                    if hint_syntax_changed
+                    else None
+                ),
             )
 
     def ensure_not_mutually_exclusive(self, *mutually_exclusive: str) -> None:
