@@ -50,6 +50,7 @@ AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED = M(
 )
 AGENT_SELF_VALIDATION_RESULT = M("AGENT_SELF_VALIDATION_RESULT")
 BAD_CLUSTER_STATE_FORMAT = M("BAD_CLUSTER_STATE_FORMAT")
+BAD_CLUSTER_STATE_DATA = M("BAD_CLUSTER_STATE_DATA")
 BOOTH_ADDRESS_DUPLICATION = M("BOOTH_ADDRESS_DUPLICATION")
 BOOTH_ALREADY_IN_CIB = M("BOOTH_ALREADY_IN_CIB")
 BOOTH_AUTHFILE_NOT_USED = M("BOOTH_AUTHFILE_NOT_USED")
@@ -71,9 +72,12 @@ BOOTH_MULTIPLE_TIMES_IN_CIB = M("BOOTH_MULTIPLE_TIMES_IN_CIB")
 BOOTH_NOT_EXISTS_IN_CIB = M("BOOTH_NOT_EXISTS_IN_CIB")
 BOOTH_PATH_NOT_EXISTS = M("BOOTH_PATH_NOT_EXISTS")
 BOOTH_PEERS_STATUS_ERROR = M("BOOTH_PEERS_STATUS_ERROR")
+BOOTH_TICKET_CHANGING_STATE = M("BOOTH_TICKET_CHANGING_STATE")
+BOOTH_TICKET_CLEANUP = M("BOOTH_TICKET_CLEANUP")
 BOOTH_TICKET_DOES_NOT_EXIST = M("BOOTH_TICKET_DOES_NOT_EXIST")
 BOOTH_TICKET_DUPLICATE = M("BOOTH_TICKET_DUPLICATE")
 BOOTH_TICKET_NAME_INVALID = M("BOOTH_TICKET_NAME_INVALID")
+BOOTH_TICKET_NOT_IN_CIB = M("BOOTH_TICKET_NOT_IN_CIB")
 BOOTH_TICKET_OPERATION_FAILED = M("BOOTH_TICKET_OPERATION_FAILED")
 BOOTH_TICKET_STATUS_ERROR = M("BOOTH_TICKET_STATUS_ERROR")
 BOOTH_UNSUPPORTED_FILE_LOCATION = M("BOOTH_UNSUPPORTED_FILE_LOCATION")
@@ -87,6 +91,13 @@ CANNOT_BAN_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED = M(
 CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED = M(
     "CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED"
 )
+STOPPING_RESOURCES_BEFORE_DELETING = M("STOPPING_RESOURCES_BEFORE_DELETING")
+STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED = M(
+    "STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED"
+)
+CANNOT_STOP_RESOURCES_BEFORE_DELETING = M(
+    "CANNOT_STOP_RESOURCES_BEFORE_DELETING"
+)
 CANNOT_CREATE_DEFAULT_CLUSTER_PROPERTY_SET = M(
     "CANNOT_CREATE_DEFAULT_CLUSTER_PROPERTY_SET"
 )
@@ -138,6 +149,8 @@ CIB_LOAD_ERROR_GET_NODES_FOR_VALIDATION = M(
 CIB_NVSET_AMBIGUOUS_PROVIDE_NVSET_ID = M("CIB_NVSET_AMBIGUOUS_PROVIDE_NVSET_ID")
 CIB_LOAD_ERROR_SCOPE_MISSING = M("CIB_LOAD_ERROR_SCOPE_MISSING")
 CIB_PUSH_ERROR = M("CIB_PUSH_ERROR")
+CIB_REMOVE_REFERENCES = M("CIB_REMOVE_REFERENCES")
+CIB_REMOVE_RESOURCES = M("CIB_REMOVE_RESOURCES")
 CIB_REMOVE_DEPENDANT_ELEMENTS = M("CIB_REMOVE_DEPENDANT_ELEMENTS")
 CIB_SAVE_TMP_ERROR = M("CIB_SAVE_TMP_ERROR")
 CIB_SIMULATE_ERROR = M("CIB_SIMULATE_ERROR")
@@ -156,6 +169,9 @@ CLUSTER_RESTART_REQUIRED_TO_APPLY_CHANGES = M(
 CLUSTER_SETUP_SUCCESS = M("CLUSTER_SETUP_SUCCESS")
 CLUSTER_START_STARTED = M("CLUSTER_START_STARTED")
 CLUSTER_START_SUCCESS = M("CLUSTER_START_SUCCESS")
+CLUSTER_STATUS_BUNDLE_MEMBER_ID_AS_IMPLICIT = M(
+    "CLUSTER_STATUS_BUNDLE_MEMBER_ID_AS_IMPLICIT"
+)
 CLUSTER_UUID_ALREADY_SET = M("CLUSTER_UUID_ALREADY_SET")
 CLUSTER_WILL_BE_DESTROYED = M("CLUSTER_WILL_BE_DESTROYED")
 COMMAND_INVALID_PAYLOAD = M("COMMAND_INVALID_PAYLOAD")
@@ -263,7 +279,6 @@ DEPRECATED_OPTION_VALUE = M("DEPRECATED_OPTION_VALUE")
 DR_CONFIG_ALREADY_EXIST = M("DR_CONFIG_ALREADY_EXIST")
 DR_CONFIG_DOES_NOT_EXIST = M("DR_CONFIG_DOES_NOT_EXIST")
 DUPLICATE_CONSTRAINTS_EXIST = M("DUPLICATE_CONSTRAINTS_EXIST")
-DUPLICATE_CONSTRAINTS_LIST = M("DUPLICATE_CONSTRAINTS_LIST")
 EMPTY_RESOURCE_SET_LIST = M("EMPTY_RESOURCE_SET_LIST")
 FENCE_HISTORY_COMMAND_ERROR = M("FENCE_HISTORY_COMMAND_ERROR")
 FENCE_HISTORY_NOT_SUPPORTED = M("FENCE_HISTORY_NOT_SUPPORTED")
@@ -443,6 +458,13 @@ RESOURCE_OPERATION_INTERVAL_DUPLICATION = M(
 )
 RESOURCE_REFRESH_ERROR = M("RESOURCE_REFRESH_ERROR")
 RESOURCE_REFRESH_TOO_TIME_CONSUMING = M("RESOURCE_REFRESH_TOO_TIME_CONSUMING")
+RESOURCE_RESTART_ERROR = M("RESOURCE_RESTART_ERROR")
+RESOURCE_RESTART_NODE_IS_FOR_MULTIINSTANCE_ONLY = M(
+    "RESOURCE_RESTART_NODE_IS_FOR_MULTIINSTANCE_ONLY"
+)
+RESOURCE_RESTART_USING_PARENT_RESOURCE = M(
+    "RESOURCE_RESTART_USING_PARENT_RESOURCE"
+)
 RESOURCE_RUNNING_ON_NODES = M("RESOURCE_RUNNING_ON_NODES")
 RESOURCE_UNMOVE_UNBAN_PCMK_ERROR = M("RESOURCE_UNMOVE_UNBAN_PCMK_ERROR")
 RESOURCE_UNMOVE_UNBAN_PCMK_SUCCESS = M("RESOURCE_UNMOVE_UNBAN_PCMK_SUCCESS")
@@ -599,7 +621,10 @@ UNSUPPORTED_OPERATION_ON_NON_SYSTEMD_SYSTEMS = M(
 )
 USE_COMMAND_NODE_ADD_REMOTE = M("USE_COMMAND_NODE_ADD_REMOTE")
 USE_COMMAND_NODE_ADD_GUEST = M("USE_COMMAND_NODE_ADD_GUEST")
+USE_COMMAND_NODE_REMOVE_REMOTE = M("USE_COMMAND_NODE_REMOVE_REMOTE")
 USE_COMMAND_NODE_REMOVE_GUEST = M("USE_COMMAND_NODE_REMOVE_GUEST")
+REMOTE_NODE_REMOVAL_INCOMPLETE = M("REMOTE_NODE_REMOVAL_INCOMPLETE")
+GUEST_NODE_REMOVAL_INCOMPLETE = M("GUEST_NODE_REMOVAL_INCOMPLETE")
 USING_DEFAULT_ADDRESS_FOR_HOST = M("USING_DEFAULT_ADDRESS_FOR_HOST")
 USING_DEFAULT_WATCHDOG = M("USING_DEFAULT_WATCHDOG")
 WAIT_FOR_IDLE_STARTED = M("WAIT_FOR_IDLE_STARTED")
