@@ -61,3 +61,8 @@ MULTIPLE_SCORE_OPTIONS = _D("MULTIPLE_SCORE_OPTIONS")
 # case
 COROSYNC_NOT_RUNNING_ON_NODE = _D("COROSYNC_NOT_RUNNING_ON_NODE")
 COROSYNC_RUNNING_ON_NODE = _D("COROSYNC_RUNNING_ON_NODE")
+
+# Removed after 0.11.7, unused after 0.11.7
+# Replaced by DUPLICATE_CONSTRAINTS_EXIST and
+# pcs.cli.reports.preprocessor.get_duplicate_constraint_exists_preprocessor
+DUPLICATE_CONSTRAINTS_LIST = _D("DUPLICATE_CONSTRAINTS_LIST")
