@@ -23,6 +23,7 @@ from pcs.cli.common.output import (
 from pcs.cli.constraint.location import command as location_command
 from pcs.cli.constraint.output import (
     CibConstraintLocationAnyDto,
+    filter_constraints_by_rule_expired_status,
     location,
     print_config,
 )
@@ -46,9 +47,8 @@ from pcs.common.pacemaker.constraint import (
     get_all_constraints_ids,
 )
 from pcs.common.pacemaker.resource.list import CibResourcesDto
+from pcs.common.pacemaker.types import CibResourceDiscovery
 from pcs.common.reports import ReportItem
-from pcs.common.reports.constraints import colocation as colocation_format
-from pcs.common.reports.constraints import order as order_format
 from pcs.common.str_tools import (
     format_list,
     indent,
@@ -62,6 +62,7 @@ from pcs.lib.cib.constraint.order import ATTRIB as order_attrib
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.pacemaker.values import (
     SCORE_INFINITY,
+    is_true,
     sanitize_id,
 )
 
@@ -316,6 +317,25 @@ def colocation_add(lib, argv, modifiers):
     for nv_pair in nv_pairs:
         element.setAttribute(nv_pair[0], nv_pair[1])
     if not modifiers.get("--force"):
+
+        def _constraint_export(constraint_info):
+            options_dict = constraint_info["options"]
+            co_resource1 = options_dict.get("rsc", "")
+            co_resource2 = options_dict.get("with-rsc", "")
+            co_id = options_dict.get("id", "")
+            co_score = options_dict.get("score", "")
+            score_text = "(score:" + co_score + ")"
+            console_option_list = [
+                f"({option[0]}:{option[1]})"
+                for option in sorted(options_dict.items())
+                if option[0] not in ("rsc", "with-rsc", "id", "score")
+            ]
+            console_option_list.append(f"(id:{co_id})")
+            return " ".join(
+                [co_resource1, "with", co_resource2, score_text]
+                + console_option_list
+            )
+
         duplicates = colocation_find_duplicates(constraintsElement, element)
         if duplicates:
             utils.err(
@@ -323,7 +343,7 @@ def colocation_add(lib, argv, modifiers):
                 + "\n".join(
                     [
                         "  "
-                        + colocation_format.constraint_plain(
+                        + _constraint_export(
                             {"options": dict(dup.attributes.items())}
                         )
                         for dup in duplicates
@@ -527,6 +547,11 @@ def _order_add(resource1, resource2, options_list, modifiers):
         if opt[0] == "score":
             scorekind = "score: " + opt[1]
             id_suffix = opt[1]
+            # TODO deprecated in pacemaker 2, to be removed in pacemaker 3
+            # added to pcs after 0.11.7
+            deprecation_warning(
+                reports.messages.DeprecatedOption(opt[0], []).message
+            )
             break
         if opt[0] == "kind":
             scorekind = "kind: " + opt[1]
@@ -546,6 +571,67 @@ def _order_add(resource1, resource2, options_list, modifiers):
         element.setAttribute(order_opt[0], order_opt[1])
     constraintsElement.appendChild(element)
     if not modifiers.get("--force"):
+
+        def _constraint_export(constraint_info):
+            options = constraint_info["options"]
+            oc_resource1 = options.get("first", "")
+            oc_resource2 = options.get("then", "")
+            first_action = options.get("first-action", "")
+            then_action = options.get("then-action", "")
+            oc_id = options.get("id", "")
+            oc_score = options.get("score", "")
+            oc_kind = options.get("kind", "")
+            oc_sym = ""
+            oc_id_out = ""
+            oc_options = ""
+            if "symmetrical" in options and not is_true(
+                options.get("symmetrical", "false")
+            ):
+                oc_sym = "(non-symmetrical)"
+            if oc_kind != "":
+                score_text = "(kind:" + oc_kind + ")"
+            elif oc_kind == "" and oc_score == "":
+                score_text = "(kind:Mandatory)"
+            else:
+                score_text = "(score:" + oc_score + ")"
+            oc_id_out = "(id:" + oc_id + ")"
+            already_processed_options = (
+                "first",
+                "then",
+                "first-action",
+                "then-action",
+                "id",
+                "score",
+                "kind",
+                "symmetrical",
+            )
+            oc_options = " ".join(
+                [
+                    f"{name}={value}"
+                    for name, value in options.items()
+                    if name not in already_processed_options
+                ]
+            )
+            if oc_options:
+                oc_options = "(Options: " + oc_options + ")"
+            return " ".join(
+                [
+                    arg
+                    for arg in [
+                        first_action,
+                        oc_resource1,
+                        "then",
+                        then_action,
+                        oc_resource2,
+                        score_text,
+                        oc_sym,
+                        oc_options,
+                        oc_id_out,
+                    ]
+                    if arg
+                ]
+            )
+
         duplicates = order_find_duplicates(constraintsElement, element)
         if duplicates:
             utils.err(
@@ -553,7 +639,7 @@ def _order_add(resource1, resource2, options_list, modifiers):
                 + "\n".join(
                     [
                         "  "
-                        + order_format.constraint_plain(
+                        + _constraint_export(
                             {"options": dict(dup.attributes.items())}
                         )
                         for dup in duplicates
@@ -696,6 +782,7 @@ def location_config_cmd(
     """
     modifiers.ensure_only_supported("-f", "--output-format", "--full", "--all")
     filter_type: Optional[str] = None
+    filter_items: parse_args.Argv = []
     if argv:
         filter_type, *filter_items = argv
         allowed_types = ("resources", "nodes")
@@ -710,9 +797,9 @@ def location_config_cmd(
                 "with grouping and filtering by nodes or resources"
             )
 
-    constraints_dto = cast(
-        CibConstraintsDto,
+    constraints_dto = filter_constraints_by_rule_expired_status(
         lib.constraint.get_config(evaluate_rules=True),
+        modifiers.is_specified("--all"),
     )
 
     constraints_dto = CibConstraintsDto(
@@ -813,6 +900,7 @@ def location_prefer(lib, argv, modifiers):
         raise CmdLineInputError()
 
     skip_node_check = False
+    existing_nodes: list[str] = []
     if modifiers.is_specified("-f") or modifiers.get("--force"):
         skip_node_check = True
         warn(LOCATION_NODE_VALIDATION_SKIP_MSG)
@@ -888,7 +976,29 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
     if argv:
         for arg in argv:
             if "=" in arg:
-                options.append(arg.split("=", 1))
+                name, value = arg.split("=", 1)
+                if name == "resource-discovery":
+                    if not modifiers.get("--force"):
+                        allowed_discovery = list(
+                            map(
+                                str,
+                                [
+                                    CibResourceDiscovery.ALWAYS,
+                                    CibResourceDiscovery.EXCLUSIVE,
+                                    CibResourceDiscovery.NEVER,
+                                ],
+                            )
+                        )
+                        if value not in allowed_discovery:
+                            utils.err(
+                                (
+                                    "invalid {0} value '{1}', allowed values are: "
+                                    "{2}, use --force to override"
+                                ).format(
+                                    name, value, format_list(allowed_discovery)
+                                )
+                            )
+                options.append([name, value])
             else:
                 raise CmdLineInputError(f"bad option '{arg}'")
             if options[-1][0] != "resource-discovery" and not modifiers.get(
@@ -1027,6 +1137,28 @@ def location_rule(lib, argv, modifiers):
     # If resource-discovery is specified, we use it with the rsc_location
     # element not the rule
     if resource_discovery:
+        if not modifiers.get("--force"):
+            allowed_discovery = list(
+                map(
+                    str,
+                    [
+                        CibResourceDiscovery.ALWAYS,
+                        CibResourceDiscovery.EXCLUSIVE,
+                        CibResourceDiscovery.NEVER,
+                    ],
+                )
+            )
+            if resource_discovery not in allowed_discovery:
+                utils.err(
+                    (
+                        "invalid {0} value '{1}', allowed values are: {2}, "
+                        "use --force to override"
+                    ).format(
+                        "resource-discovery",
+                        resource_discovery,
+                        format_list(allowed_discovery),
+                    )
+                )
         lc.setAttribute("resource-discovery", options.pop("resource-discovery"))
 
     constraints.appendChild(lc)
@@ -1165,12 +1297,11 @@ def constraint_rm(
 
     c_id = argv.pop(0)
     elementFound = False
-
+    dom = None
+    use_cibadmin = False
     if not constraintsElement:
         (dom, constraintsElement) = getCurrentConstraints(passed_dom)
         use_cibadmin = True
-    else:
-        use_cibadmin = False
 
     for co in constraintsElement.childNodes[:]:
         if co.nodeType != xml.dom.Node.ELEMENT_NODE:
@@ -1362,30 +1493,6 @@ def remove_constraints_containing(
     return None
 
 
-def remove_constraints_containing_node(dom, node, output=False):
-    """
-    Commandline options: no options
-    """
-    for constraint in find_constraints_containing_node(dom, node):
-        if output:
-            print_to_stderr(
-                "Removing Constraint - {}".format(constraint.getAttribute("id"))
-            )
-        constraint.parentNode.removeChild(constraint)
-    return dom
-
-
-def find_constraints_containing_node(dom, node):
-    """
-    Commandline options: no options
-    """
-    return [
-        constraint
-        for constraint in dom.getElementsByTagName("rsc_location")
-        if constraint.getAttribute("node") == node
-    ]
-
-
 # Re-assign any constraints referencing a resource to its parent (a clone
 # or master)
 def constraint_resource_update(old_id, dom):
@@ -1415,6 +1522,13 @@ def constraint_rule_add(lib, argv, modifiers):
       * -f - CIB file
       * --force - allow duplicate constraints
     """
+    # deprecated in pacemaker 2, removed in pacemaker 3
+    # added to pcs after 0.11.8
+    # the whole command removed in pcs-0.12
+    deprecation_warning(
+        "The possibility of defining multiple rules in a single location "
+        "constraint is deprecated and will be removed."
+    )
     del lib
     modifiers.ensure_only_supported("-f", "--force")
     if not argv:
