@@ -8,7 +8,9 @@ from typing import (
 from pcs.lib.commands import (  # services,
     acl,
     alert,
+    booth,
     cib,
+    cib_options,
     cluster,
     cluster_property,
     constraint,
@@ -23,6 +25,7 @@ from pcs.lib.commands import (  # services,
     status,
     stonith,
     stonith_agent,
+    tag,
 )
 from pcs.lib.permissions.config.types import PermissionAccessType as p
 
@@ -106,6 +109,18 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=alert.update_recipient,
         required_permission=p.WRITE,
     ),
+    "booth.ticket_cleanup": _Cmd(
+        cmd=booth.ticket_cleanup,
+        required_permission=p.WRITE,
+    ),
+    "booth.ticket_standby": _Cmd(
+        cmd=booth.ticket_standby,
+        required_permission=p.WRITE,
+    ),
+    "booth.ticket_unstandby": _Cmd(
+        cmd=booth.ticket_unstandby,
+        required_permission=p.WRITE,
+    ),
     "cluster.add_nodes": _Cmd(
         cmd=cluster.add_nodes,
         required_permission=p.FULL,
@@ -114,6 +129,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=cluster.generate_cluster_uuid,
         required_permission=p.SUPERUSER,
     ),
+    "cluster.get_corosync_conf_struct": _Cmd(
+        cmd=cluster.get_corosync_conf_struct,
+        required_permission=p.READ,
+    ),
     "cluster.node_clear": _Cmd(
         cmd=cluster.node_clear,
         required_permission=p.WRITE,
@@ -138,10 +157,22 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=cluster_property.set_properties,
         required_permission=p.WRITE,
     ),
+    "cluster.wait_for_pcmk_idle": _Cmd(
+        cmd=cluster.wait_for_pcmk_idle,
+        required_permission=p.READ,
+    ),
     "cib.remove_elements": _Cmd(
         cmd=cib.remove_elements,
         required_permission=p.WRITE,
     ),
+    "cib_options.operation_defaults_config": _Cmd(
+        cmd=cib_options.operation_defaults_config,
+        required_permission=p.READ,
+    ),
+    "cib_options.resource_defaults_config": _Cmd(
+        cmd=cib_options.resource_defaults_config,
+        required_permission=p.READ,
+    ),
     "constraint.colocation.create_with_set": _Cmd(
         cmd=constraint.colocation.create_with_set,
         required_permission=p.WRITE,
@@ -170,6 +201,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=fencing_topology.add_level,
         required_permission=p.WRITE,
     ),
+    "fencing_topology.get_config_dto": _Cmd(
+        cmd=fencing_topology.get_config_dto,
+        required_permission=p.READ,
+    ),
     "fencing_topology.remove_all_levels": _Cmd(
         cmd=fencing_topology.remove_all_levels,
         required_permission=p.WRITE,
@@ -304,6 +339,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=resource.enable,
         required_permission=p.WRITE,
     ),
+    "resource.get_configured_resources": _Cmd(
+        cmd=resource.get_configured_resources,
+        required_permission=p.READ,
+    ),
     "resource.group_add": _Cmd(
         cmd=resource.group_add,
         required_permission=p.WRITE,
@@ -320,6 +359,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=resource.move_autoclean,
         required_permission=p.WRITE,
     ),
+    "resource.restart": _Cmd(
+        cmd=resource.restart,
+        required_permission=p.WRITE,
+    ),
     "resource.unmanage": _Cmd(
         cmd=resource.unmanage,
         required_permission=p.WRITE,
@@ -349,6 +392,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=status.full_cluster_status_plaintext,
         required_permission=p.READ,
     ),
+    "status.resources_status": _Cmd(
+        cmd=status.resources_status,
+        required_permission=p.READ,
+    ),
     # deprecated, API v1 compatibility
     "stonith_agent.describe_agent": _Cmd(
         cmd=stonith_agent.describe_agent,
@@ -367,6 +414,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=stonith.create_in_group,
         required_permission=p.WRITE,
     ),
+    "tag.get_config_dto": _Cmd(
+        cmd=tag.get_config_dto,
+        required_permission=p.READ,
+    ),
     # CMDs allowed in pcs_internal but not exposed via REST API:
     # "services.disable_service": Cmd(services.disable_service,
     # "services.enable_service": Cmd(services.enable_service,
