@@ -1,3 +1,4 @@
+import multiprocessing as mp
 import os
 import signal
 import socket
@@ -88,8 +89,10 @@ def configure_app(
     session_storage: session.Storage,
     ruby_pcsd_wrapper: ruby_pcsd.Wrapper,
     sync_config_lock: Lock,
-    public_dir: str,
+    webui_dir: str,
+    webui_fallback: str,
     pcsd_capabilities: Iterable[capabilities.Capability],
+    *,
     disable_gui: bool = False,
     debug: bool = False,
 ):
@@ -122,11 +125,8 @@ def configure_app(
                 [(r"/(ui)?", RedirectHandler, dict(url="/ui/"))]
                 + ui.get_routes(
                     url_prefix="/ui/",
-                    app_dir=os.path.join(public_dir, "ui"),
-                    fallback_page_path=os.path.join(
-                        public_dir,
-                        "ui_instructions.html",
-                    ),
+                    app_dir=webui_dir,
+                    fallback_page_path=webui_fallback,
                     session_storage=session_storage,
                     auth_provider=auth_provider,
                 )
@@ -157,6 +157,12 @@ def _print_version(argv: StringCollection) -> None:
 
 
 def main(argv=None) -> None:
+    # set the way how processes are started
+    # https://docs.python.org/3/library/multiprocessing.html#contexts-and-start-methods
+    # avoid deadlock in multiprocessing.pool.Pool on terminate
+    # https://github.com/python/cpython/issues/73945
+    mp.set_start_method(method="forkserver")
+
     argv = argv if argv is not None else sys.argv[1:]
     if "--version" in argv:
         _print_version(argv)
@@ -213,7 +219,8 @@ def main(argv=None) -> None:
         session.Storage(env.PCSD_SESSION_LIFETIME),
         ruby_pcsd_wrapper,
         sync_config_lock,
-        env.PCSD_STATIC_FILES_DIR,
+        env.WEBUI_DIR,
+        env.WEBUI_FALLBACK,
         pcsd_capabilities,
         disable_gui=env.PCSD_DISABLE_GUI,
         debug=env.PCSD_DEV,
