@@ -24,7 +24,6 @@ from pcs.lib.cib.tools import (
 from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.values import is_true
 from pcs.lib.tools import get_optional_value
-from pcs.lib.xml_tools import export_attributes
 
 _ATTRIBUTES = ("action", "require-all", "role", "sequential")
 
@@ -93,13 +92,6 @@ def get_resource_id_set_list(element):
     ]
 
 
-def export(element):
-    return {
-        "ids": get_resource_id_set_list(element),
-        "options": export_attributes(element),
-    }
-
-
 def is_resource_in_same_group(cib, resource_id_list):
     # We don't care about not found elements here, that is a job of another
     # validator. We do not care if the id doesn't belong to a resource either
@@ -120,10 +112,6 @@ def is_resource_in_same_group(cib, resource_id_list):
         )
 
 
-def is_set_constraint(constraint_el: etree._Element) -> bool:
-    return constraint_el.find("./resource_set") is not None
-
-
 def _resource_set_element_to_dto(
     resource_set_el: etree._Element,
 ) -> CibResourceSetDto:
