@@ -1,18 +1,32 @@
+from collections.abc import Sequence
 from typing import (
+    Any,
+    Final,
     Optional,
-    Sequence,
-    Set,
-    Tuple,
+    Type,
+    TypeVar,
+    cast,
 )
 
 from lxml import etree
-from lxml.etree import _Element
+from lxml.etree import (
+    _Attrib,
+    _Element,
+)
 
 from pcs.common import reports
 from pcs.common.fencing_topology import (
     TARGET_TYPE_ATTRIBUTE,
     TARGET_TYPE_NODE,
     TARGET_TYPE_REGEXP,
+    FencingTargetType,
+    FencingTargetValue,
+)
+from pcs.common.pacemaker.fencing_topology import (
+    CibFencingLevelAttributeDto,
+    CibFencingLevelNodeDto,
+    CibFencingLevelRegexDto,
+    CibFencingTopologyDto,
 )
 from pcs.common.reports import (
     ReportItemList,
@@ -22,9 +36,19 @@ from pcs.common.reports import (
 from pcs.common.reports import codes as report_codes
 from pcs.common.reports import has_errors
 from pcs.common.reports.item import ReportItem
-from pcs.common.types import StringCollection
-from pcs.lib.cib.resource.stonith import is_stonith_resource
-from pcs.lib.cib.tools import find_unique_id
+from pcs.common.types import StringSequence
+from pcs.common.validate import is_integer
+from pcs.lib.cib.const import TAG_FENCING_LEVEL
+from pcs.lib.cib.resource.stonith import is_stonith
+from pcs.lib.cib.tools import (
+    ElementNotFound,
+    IdProvider,
+    get_element_by_id,
+    get_fencing_topology,
+    multivalue_attr_contains_value,
+    multivalue_attr_delete_value,
+    multivalue_attr_has_any_values,
+)
 from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.state import _Element as StateElement
 from pcs.lib.pacemaker.values import (
@@ -32,44 +56,75 @@ from pcs.lib.pacemaker.values import (
     validate_id,
 )
 
+_DEVICES_ATTRIBUTE: Final = "devices"
+
+FencingLevelDto = TypeVar(
+    "FencingLevelDto",
+    CibFencingLevelAttributeDto,
+    CibFencingLevelNodeDto,
+    CibFencingLevelRegexDto,
+)
+
+
+def _generate_level_id(
+    id_provider: IdProvider,
+    level: str,
+    target_type: FencingTargetType,
+    target_value: FencingTargetValue,
+) -> str:
+    if target_type == TARGET_TYPE_ATTRIBUTE:
+        # For attribute target type, the value is tuple[str, str]
+        id_part = target_value[0]
+    else:
+        # For all other target types, the value is str
+        id_part = str(target_value)
+    return id_provider.allocate_id(sanitize_id(f"fl-{id_part}-{level}"))
+
 
 def add_level(
     reporter: ReportProcessor,
-    topology_el: _Element,
-    resources_el: _Element,
-    level,
-    target_type,
-    target_value,
-    devices,
+    cib: _Element,
+    level: str,
+    target_type: FencingTargetType,
+    target_value: FencingTargetValue,
+    devices: StringSequence,
     cluster_status_nodes: Sequence[StateElement],
-    force_device=False,
-    force_node=False,
-):
+    level_id: Optional[str] = None,
+    force_device: bool = False,
+    force_node: bool = False,
+) -> None:
     """
     Validate and add a new fencing level. Raise LibraryError if not valid.
 
     reporter -- report processor
-    etree topology_el -- etree element to add the level to
-    etree resources_el -- etree element with resources definitions
-    int|string level -- level (index) of the new fencing level
-    constant target_type -- the new fencing level target value type
-    mixed target_value -- the new fencing level target value
-    Iterable devices -- list of stonith devices for the new fencing level
-    Iterable cluster_status_nodes -- list of status of existing cluster nodes
-    bool force_device -- continue even if a stonith device does not exist
-    bool force_node -- continue even if a node (target) does not exist
+    cib -- the whole cib
+    level -- level (index) of the new fencing level
+    target_type -- the new fencing level target value type
+    target_value -- the new fencing level target value
+    devices -- list of stonith devices for the new fencing level
+    cluster_status_nodes -- list of status of existing cluster nodes
+    level_id -- user specified id for the level element
+    force_device -- continue even if a stonith device does not exist
+    force_node -- continue even if a node (target) does not exist
     """
     # pylint: disable=too-many-arguments
-    report_list, valid_level = _validate_level(level)
+    # pylint: disable=too-many-positional-arguments
+    id_provider = IdProvider(cib)
+    validate_id_reports: ReportItemList = []
+    if level_id is not None:
+        validate_id(level_id, "fencing level id", reporter=validate_id_reports)
     reporter.report_list(
-        report_list
+        (id_provider.book_ids(level_id) if level_id else [])
+        + validate_id_reports
+        + _validate_level(level)
         + _validate_target(
             cluster_status_nodes, target_type, target_value, force_node
         )
-        + _validate_devices(resources_el, devices, force_device)
+        + _validate_devices(cib, devices, force_device)
     )
     if reporter.has_errors:
         raise LibraryError()
+    topology_el = get_fencing_topology(cib)
     reporter.report_list(
         _validate_level_target_devices_does_not_exist(
             topology_el, level, target_type, target_value, devices
@@ -78,14 +133,22 @@ def add_level(
     if reporter.has_errors:
         raise LibraryError()
     _append_level_element(
-        topology_el, valid_level, target_type, target_value, devices
+        topology_el,
+        level,
+        target_type,
+        target_value,
+        devices,
+        (
+            level_id
+            or _generate_level_id(id_provider, level, target_type, target_value)
+        ),
     )
 
 
-def remove_all_levels(topology_el):
+def remove_all_levels(topology_el: _Element) -> None:
     """
     Remove all fencing levels.
-    etree topology_el -- etree element to remove the levels from
+    topology_el -- etree element to remove the levels from
     """
     # Do not ever remove a fencing-topology element, even if it is empty. There
     # may be ACLs set in pacemaker which allow "write" for fencing-level
@@ -94,17 +157,17 @@ def remove_all_levels(topology_el):
     # the whole change to be rejected by pacemaker with a "permission denied"
     # message.
     # https://bugzilla.redhat.com/show_bug.cgi?id=1642514
-    for level_el in topology_el.findall("fencing-level"):
-        level_el.getparent().remove(level_el)
+    for level_el in topology_el.findall(TAG_FENCING_LEVEL):
+        # Parent is guaranteed by CIB schema
+        cast(_Element, level_el.getparent()).remove(level_el)
 
 
 def remove_levels_by_params(
     topology_el: _Element,
-    level=None,
-    # TODO create a special type, so that it cannot accept any string
-    target_type: Optional[str] = None,
-    target_value=None,
-    devices: Optional[StringCollection] = None,
+    level: Optional[str] = None,
+    target_type: Optional[FencingTargetType] = None,
+    target_value: Optional[FencingTargetValue] = None,
+    devices: Optional[StringSequence] = None,
     # TODO remove, deprecated backward compatibility layer
     ignore_if_missing: bool = False,
     # TODO remove, deprecated backward compatibility layer
@@ -114,9 +177,9 @@ def remove_levels_by_params(
     Remove specified fencing level(s)
 
     topology_el -- etree element to remove the levels from
-    int|string level -- level (index) of the fencing level to remove
+    level -- level (index) of the fencing level to remove
     target_type -- the removed fencing level target value type
-    mixed target_value -- the removed fencing level target value
+    target_value -- the removed fencing level target value
     devices -- list of stonith devices of the removed fencing level
     ignore_if_missing -- when True, do not report if level not found
     """
@@ -149,7 +212,7 @@ def remove_levels_by_params(
         report_list.append(
             ReportItem.error(
                 reports.messages.CibFencingLevelDoesNotExist(
-                    level,
+                    level or "",
                     target_type,
                     target_value,
                     sorted(devices) if devices else [],
@@ -159,37 +222,51 @@ def remove_levels_by_params(
     if has_errors(report_list):
         return report_list
     for el in level_el_list:
-        el.getparent().remove(el)
+        # Parent guaranteed by CIB schema
+        cast(_Element, el.getparent()).remove(el)
     return report_list
 
 
-def remove_device_from_all_levels(topology_el, device_id):
+def find_levels_with_device(
+    topology_el: _Element, device_id: str
+) -> list[_Element]:
     """
-    Remove specified stonith device from all fencing levels.
+    Return list of all fencing-level elements that reference the specified
+    device
 
-    etree topology_el -- etree element with levels to remove the device from
-    string device_id -- stonith device to remove
+    topology_el -- etree element with fencing levels
+    device_id -- id of the stonith device
     """
-    # Do not ever remove a fencing-topology element, even if it is empty. There
-    # may be ACLs set in pacemaker which allow "write" for fencing-level
-    # elements (adding, changing and removing) but not fencing-topology
-    # elements. In such a case, removing a fencing-topology element would cause
-    # the whole change to be rejected by pacemaker with a "permission denied"
-    # message.
-    # https://bugzilla.redhat.com/show_bug.cgi?id=1642514
-    for level_el in topology_el.findall("fencing-level"):
-        new_devices = [
-            dev
-            for dev in level_el.get("devices").split(",")
-            if dev != device_id
-        ]
-        if new_devices:
-            level_el.set("devices", ",".join(new_devices))
-        else:
-            level_el.getparent().remove(level_el)
+    return [
+        level_el
+        for level_el in topology_el.findall(TAG_FENCING_LEVEL)
+        if multivalue_attr_contains_value(
+            level_el, _DEVICES_ATTRIBUTE, device_id
+        )
+    ]
 
 
-def export(topology_el):
+def remove_device_from_level(level_el: _Element, device_id: str) -> None:
+    """
+    Remove specified stonith device from fencing level.
+
+    level_el -- level element from which the device is removed
+    device_id -- stonith device to remove
+    """
+    multivalue_attr_delete_value(level_el, _DEVICES_ATTRIBUTE, device_id)
+
+
+def has_any_devices(level_el: _Element) -> bool:
+    """
+    Return whether there are any devices references in the fencing level
+
+    level_el -- fencing level element
+    """
+    return multivalue_attr_has_any_values(level_el, _DEVICES_ATTRIBUTE)
+
+
+# DEPRECATED, use fencing_topology_el_to_dto
+def export(topology_el: _Element) -> list[dict[str, Any]]:
     """
     Export all fencing levels.
 
@@ -199,8 +276,9 @@ def export(topology_el):
     etree topology_el -- etree element to export
     """
     export_levels = []
-    for level_el in topology_el.iterfind("fencing-level"):
-        target_type = target_value = None
+    for level_el in topology_el.iterfind(TAG_FENCING_LEVEL):
+        target_type: Optional[FencingTargetType] = None
+        target_value: Optional[FencingTargetValue] = None
         if "target" in level_el.attrib:
             target_type = TARGET_TYPE_NODE
             target_value = level_el.get("target")
@@ -210,8 +288,8 @@ def export(topology_el):
         elif "target-attribute" in level_el.attrib:
             target_type = TARGET_TYPE_ATTRIBUTE
             target_value = (
-                level_el.get("target-attribute"),
-                level_el.get("target-value"),
+                str(level_el.attrib["target-attribute"]),
+                str(level_el.attrib["target-value"]),
             )
         if target_type and target_value:
             export_levels.append(
@@ -219,38 +297,101 @@ def export(topology_el):
                     "target_type": target_type,
                     "target_value": target_value,
                     "level": level_el.get("index"),
-                    "devices": level_el.get("devices").split(","),
+                    "devices": str(level_el.attrib[_DEVICES_ATTRIBUTE]).split(
+                        ","
+                    ),
                 }
             )
     return export_levels
 
 
+def _fencing_level_dto_factory(
+    dto_type: Type[FencingLevelDto],
+    level_el_attrib: _Attrib,
+) -> FencingLevelDto:
+    if dto_type is CibFencingLevelRegexDto:
+        target_args = {"target_pattern": str(level_el_attrib["target-pattern"])}
+    elif dto_type is CibFencingLevelAttributeDto:
+        target_args = {
+            "target_attribute": str(level_el_attrib["target-attribute"]),
+            "target_value": str(level_el_attrib["target-value"]),
+        }
+    else:
+        target_args = {"target": str(level_el_attrib["target"])}
+
+    return dto_type(
+        id=str(level_el_attrib["id"]),
+        index=int(level_el_attrib["index"]),
+        devices=[
+            device.strip()
+            for device in str(level_el_attrib["devices"]).split(",")
+        ],
+        **target_args,
+    )
+
+
+def fencing_topology_el_to_dto(
+    fencing_topology_el: _Element,
+) -> CibFencingTopologyDto:
+    level_el_list = _find_all_level_elements(fencing_topology_el)
+    target_node_list = []
+    target_regex_list = []
+    target_attr_list = []
+    for level_el in level_el_list:
+        if "target" in level_el.attrib:
+            target_node_list.append(
+                _fencing_level_dto_factory(
+                    CibFencingLevelNodeDto,
+                    level_el.attrib,
+                )
+            )
+        if "target-pattern" in level_el.attrib:
+            target_regex_list.append(
+                _fencing_level_dto_factory(
+                    CibFencingLevelRegexDto,
+                    level_el.attrib,
+                )
+            )
+        if "target-attribute" in level_el.attrib:
+            target_attr_list.append(
+                _fencing_level_dto_factory(
+                    CibFencingLevelAttributeDto,
+                    level_el.attrib,
+                )
+            )
+
+    return CibFencingTopologyDto(
+        target_node=target_node_list,
+        target_regex=target_regex_list,
+        target_attribute=target_attr_list,
+    )
+
+
 def verify(
-    topology_el: _Element,
-    resources_el: _Element,
+    cib: _Element,
     cluster_status_nodes: Sequence[StateElement],
 ) -> ReportItemList:
     """
     Check if all cluster nodes and stonith devices used in fencing levels exist.
 
-    topology_el -- fencing levels to check
-    resources_el -- resources definitions
+    cib -- the whole cib
     cluster_status_nodes -- list of status of existing cluster nodes
     """
     report_list: ReportItemList = []
-    used_nodes: Set[str] = set()
-    used_devices: Set[str] = set()
+    used_nodes: set[str] = set()
+    used_devices: set[str] = set()
+    topology_el = get_fencing_topology(cib)
 
-    for level_el in topology_el.iterfind("fencing-level"):
-        used_devices.update(str(level_el.get("devices", "")).split(","))
+    for level_el in topology_el.iterfind(TAG_FENCING_LEVEL):
+        used_devices.update(
+            str(level_el.get(_DEVICES_ATTRIBUTE, "")).split(",")
+        )
         if "target" in level_el.attrib:
             used_nodes.add(str(level_el.get("target", "")))
 
     if used_devices:
         report_list.extend(
-            _validate_devices(
-                resources_el, sorted(used_devices), allow_force=False
-            )
+            _validate_devices(cib, sorted(used_devices), allow_force=False)
         )
 
     for node in sorted(used_nodes):
@@ -262,36 +403,29 @@ def verify(
     return report_list
 
 
-def _validate_level(level) -> Tuple[ReportItemList, Optional[int]]:
+def _validate_level(level: str) -> ReportItemList:
     report_list: ReportItemList = []
-    try:
-        candidate = int(level)
-        if candidate > 0:
-            return report_list, candidate
-    except ValueError:
-        pass
-    report_list.append(
-        ReportItem.error(
-            reports.messages.InvalidOptionValue(
-                "level", level, "a positive integer"
+    if not is_integer(level, 1, 9):
+        report_list.append(
+            ReportItem.error(
+                reports.messages.InvalidOptionValue("level", str(level), "1..9")
             )
         )
-    )
-    return report_list, None
+    return report_list
 
 
 def _validate_target(
     cluster_status_nodes: Sequence[StateElement],
-    target_type,
-    target_value,
-    force_node=False,
+    target_type: FencingTargetType,
+    target_value: FencingTargetValue,
+    force_node: bool = False,
 ) -> ReportItemList:
     return _validate_target_typewise(target_type) + _validate_target_valuewise(
         cluster_status_nodes, target_type, target_value, force_node
     )
 
 
-def _validate_target_typewise(target_type) -> ReportItemList:
+def _validate_target_typewise(target_type: FencingTargetType) -> ReportItemList:
     report_list: ReportItemList = []
     if target_type not in [
         TARGET_TYPE_NODE,
@@ -311,10 +445,10 @@ def _validate_target_typewise(target_type) -> ReportItemList:
 
 def _validate_target_valuewise(
     cluster_status_nodes: Sequence[StateElement],
-    target_type,
-    target_value,
-    force_node=False,
-    allow_force=True,
+    target_type: FencingTargetType,
+    target_value: FencingTargetValue,
+    force_node: bool = False,
+    allow_force: bool = True,
 ) -> ReportItemList:
     report_list: ReportItemList = []
     if target_type == TARGET_TYPE_NODE:
@@ -338,14 +472,20 @@ def _validate_target_valuewise(
                             else report_codes.FORCE
                         ),
                     ),
-                    message=reports.messages.NodeNotFound(target_value),
+                    message=reports.messages.NodeNotFound(
+                        # This is a str based on target_type
+                        str(target_value)
+                    ),
                 )
             )
     return report_list
 
 
 def _validate_devices(
-    resources_el: _Element, devices, force_device=False, allow_force=True
+    cib: _Element,
+    devices: StringSequence,
+    force_device: bool = False,
+    allow_force: bool = True,
 ) -> ReportItemList:
     report_list: ReportItemList = []
     if not devices:
@@ -363,8 +503,10 @@ def _validate_devices(
         report_list.extend(validate_id_report_list)
         if has_errors(validate_id_report_list):
             continue
-        # TODO use the new finding function
-        if not is_stonith_resource(resources_el, dev):
+        try:
+            if not is_stonith(get_element_by_id(cib, dev)):
+                invalid_devices.append(dev)
+        except ElementNotFound:
             invalid_devices.append(dev)
     if invalid_devices:
         report_list.append(
@@ -390,54 +532,72 @@ def _validate_devices(
 
 
 def _validate_level_target_devices_does_not_exist(
-    tree, level, target_type, target_value, devices
+    tree: _Element,
+    level: str,
+    target_type: FencingTargetType,
+    target_value: FencingTargetValue,
+    devices: StringSequence,
 ) -> ReportItemList:
     report_list: ReportItemList = []
     if _find_level_elements(tree, level, target_type, target_value, devices):
         report_list.append(
             ReportItem.error(
                 reports.messages.CibFencingLevelAlreadyExists(
-                    level, target_type, target_value, devices
+                    level, target_type, target_value, list(devices)
                 )
             )
         )
     return report_list
 
 
-def _append_level_element(tree, level, target_type, target_value, devices):
+def _append_level_element(
+    tree: _Element,
+    level: str,
+    target_type: FencingTargetType,
+    target_value: FencingTargetValue,
+    devices: StringSequence,
+    level_id: str,
+) -> _Element:
     level_el = etree.SubElement(
-        tree, "fencing-level", index=str(level), devices=",".join(devices)
+        tree,
+        TAG_FENCING_LEVEL,
+        index=level,
+        devices=",".join(devices),
+        id=level_id,
     )
     if target_type == TARGET_TYPE_NODE:
-        level_el.set("target", target_value)
-        id_part = target_value
+        level_el.set("target", str(target_value))
     elif target_type == TARGET_TYPE_REGEXP:
-        level_el.set("target-pattern", target_value)
-        id_part = target_value
+        level_el.set("target-pattern", str(target_value))
     elif target_type == TARGET_TYPE_ATTRIBUTE:
         level_el.set("target-attribute", target_value[0])
         level_el.set("target-value", target_value[1])
-        id_part = target_value[0]
-    level_el.set(
-        "id",
-        find_unique_id(tree, sanitize_id(f"fl-{id_part}-{level}")),
-    )
     return level_el
 
 
+def _find_all_level_elements(tree: _Element) -> list[_Element]:
+    return tree.findall(TAG_FENCING_LEVEL)
+
+
 def _find_level_elements(
-    tree, level=None, target_type=None, target_value=None, devices=None
-):
-    xpath_vars = {}
+    tree: _Element,
+    level: Optional[str] = None,
+    target_type: Optional[FencingTargetType] = None,
+    target_value: Optional[FencingTargetValue] = None,
+    devices: Optional[StringSequence] = None,
+) -> list[_Element]:
+    xpath_vars: dict[str, str] = {}
 
     xpath_target = ""
     if target_type and target_value:
         if target_type == TARGET_TYPE_NODE:
             xpath_target = "@target=$var_target"
-            xpath_vars["var_target"] = target_value
+            # The value of xpath_target determines that this is a string
+            xpath_vars["var_target"] = str(target_value)
         elif target_type == TARGET_TYPE_REGEXP:
             xpath_target = "@target-pattern=$var_target_pattern"
-            xpath_vars["var_target_pattern"] = target_value
+            # The value of xpath_target determines that this is a string
+            xpath_vars["var_target_pattern"] = str(target_value)
         elif target_type == TARGET_TYPE_ATTRIBUTE:
             xpath_target = (
                 "@target-attribute=$var_target_attribute "
@@ -457,9 +617,10 @@ def _find_level_elements(
     )
     if xpath_attrs:
         return tree.xpath(
-            f"fencing-level[{xpath_attrs}]",
+            f"{TAG_FENCING_LEVEL}[{xpath_attrs}]",
             var_devices=(",".join(devices) if devices else ""),
-            var_level=level,
-            **xpath_vars,
+            var_level=level or "",
+            **xpath_vars,  # type: ignore
         )
-    return tree.findall("fencing-level")
+
+    return _find_all_level_elements(tree)
