@@ -235,6 +235,7 @@ def append_new(
     meta_attributes,
 ):
     # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-positional-arguments
     """
     Create new bundle and add it to the CIB
 
@@ -351,6 +352,7 @@ def validate_update(
     force_options=False,
 ):
     # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-positional-arguments
     """
     Validate modifying an existing bundle, return list of report items
 
@@ -395,6 +397,7 @@ def update(
     meta_attributes,
 ):
     # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-positional-arguments
     """
     Modify an existing bundle (does not touch encapsulated resources)
 
@@ -524,7 +527,22 @@ def _validate_container(container_type, container_options, force_options=False):
                 )
             )
         ]
-    return _validate_generic_container_options(container_options, force_options)
+    report_list = []
+    if container_type == "rkt":
+        # TODO deprecated in pacemaker 2, to be removed in pacemaker 3
+        # added to pcs after 0.11.7
+        report_list.append(
+            reports.ReportItem.deprecation(
+                reports.messages.DeprecatedOptionValue(
+                    "container type", container_type
+                )
+            )
+        )
+
+    report_list += _validate_generic_container_options(
+        container_options, force_options
+    )
+    return report_list
 
 
 def _validate_generic_container_options(container_options, force_options=False):
