@@ -186,7 +186,7 @@ def __build_date_inrange_expr(
 def __build_datespec_expr(parse_result: pyparsing.ParseResults) -> RuleExprPart:
     # Those attrs are defined by setResultsName in datespec_expr grammar rule
     return DatespecExpr(
-        parse_result.datespec.as_list() if parse_result.datespec else None
+        parse_result.datespec.as_list() if parse_result.datespec else ()
     )
 
 
@@ -212,9 +212,11 @@ def __build_node_attr_binary_expr(
         _token_to_node_expr_binary_op[parse_result.operator],
         parse_result.attr_name,
         parse_result.attr_value,
-        _token_to_node_expr_type[parse_result.attr_type]
-        if parse_result.attr_type
-        else None,
+        (
+            _token_to_node_expr_type[parse_result.attr_type]
+            if parse_result.attr_type
+            else None
+        ),
     )
 
 
