@@ -3,7 +3,6 @@ from collections import Counter
 from typing import (
     List,
     Set,
-    cast,
 )
 
 from dateutil import parser as dateutil_parser
@@ -88,17 +87,23 @@ class Validator:
         # TODO This is taken from the CIB schema. There is an ongoing
         # discussion that the schema doesn't match Pacemaker Explained. Based
         # on the result of the discussion, this might need to be updated.
+        # TODO This is planned to be updated in Pacemaker 3 and corresponding
+        # pcs version.
         duration_parts = {
             "hours",
-            "monthdays",
-            "weekdays",
-            "yearsdays",
             "months",
             "weeks",
             "years",
+        }
+        # Options planned to be removed in pacemaker 3
+        deprecated_parts = {
+            "monthdays",
+            "weekdays",
             "weekyears",
+            "yearsdays",
             "moon",
         }
+        all_duration_parts = duration_parts | deprecated_parts
         start_date, end_date = None, None
         report_list = []
 
@@ -125,17 +130,19 @@ class Validator:
                     )
                 )
         if (
-            start_date is not None
+            # start and end dates have been specified
+            expr.date_start is not None
+            and expr.date_end is not None
+            # start and end dates are valid dates
+            and start_date is not None
             and end_date is not None
+            # start happens later than end
             and start_date >= end_date
         ):
             report_list.append(
                 reports.item.ReportItem.error(
                     message=reports.messages.RuleExpressionSinceGreaterThanUntil(
-                        expr.date_start,
-                        # If end_date is not None, then expr.date_end is not
-                        # None, but mypy does not see it.
-                        cast(str, expr.date_end),
+                        expr.date_start, expr.date_end
                     ),
                 )
             )
@@ -150,10 +157,15 @@ class Validator:
             }
             validator_list: List[validate.ValidatorInterface] = [
                 validate.ValuePositiveInteger(name)
-                for name in sorted(duration_parts)
+                for name in sorted(all_duration_parts)
             ]
             validator_list.append(
-                validate.NamesIn(duration_parts, option_type="duration")
+                validate.NamesIn(all_duration_parts, option_type="duration")
+            )
+            validator_list.append(
+                validate.DeprecatedOption(
+                    deprecated_parts, [], option_type="duration"
+                )
             )
             report_list += validate.ValidatorAll(validator_list).validate(
                 dict(expr.duration_parts)
@@ -174,17 +186,23 @@ class Validator:
         # TODO This is taken from the CIB schema. There is an ongoing
         # discussion that the schema doesn't match Pacemaker Explained. Based
         # on the result of the discussion, this might need to be updated.
+        # TODO This is planned to be updated in Pacemaker 3 and corresponding
+        # pcs version.
         part_limits = {
             "hours": (0, 23),
             "monthdays": (1, 31),
             "weekdays": (1, 7),
-            "yearsdays": (1, 366),
             "months": (1, 12),
             "weeks": (1, 53),
             "years": (None, None),
             "weekyears": (None, None),
+        }
+        # Options planned to be removed in pacemaker 3
+        deprecated_part_limits = {
+            "yearsdays": (1, 366),
             "moon": (0, 7),
         }
+        all_part_limits = part_limits | deprecated_part_limits
 
         duplicate_keys = {
             key
@@ -195,10 +213,15 @@ class Validator:
         }
         validator_list: List[validate.ValidatorInterface] = [
             validate.ValuePcmkDatespecPart(name, limits[0], limits[1])
-            for name, limits in sorted(part_limits.items())
+            for name, limits in sorted(all_part_limits.items())
         ]
         validator_list.append(
-            validate.NamesIn(part_limits.keys(), option_type="datespec")
+            validate.NamesIn(all_part_limits.keys(), option_type="datespec")
+        )
+        validator_list.append(
+            validate.DeprecatedOption(
+                deprecated_part_limits, [], option_type="datespec"
+            )
         )
 
         report_list = validate.ValidatorAll(validator_list).validate(
