@@ -189,7 +189,7 @@ class ElementSearcher:
                 ReportItem.error(
                     reports.messages.IdBelongsToUnexpectedType(
                         self._element_id,
-                        expected_types=self._expected_types,
+                        expected_types=sorted(self._expected_types),
                         current_type=element.tag,
                     )
                 )
@@ -447,7 +447,7 @@ def get_crm_config(tree: _Element) -> _Element:
     return sections.get(tree, sections.CRM_CONFIG)
 
 
-def get_fencing_topology(tree):
+def get_fencing_topology(tree: _Element) -> _Element:
     """
     Return the 'fencing-topology' element from the tree
     tree -- cib etree node
@@ -559,25 +559,6 @@ def _get_configuration(element: _Element) -> _Element:
     return get_configuration(get_root(element))
 
 
-def _find_elements_without_id_referencing_id(
-    element: _Element,
-    referenced_id: str,
-) -> list[_Element]:
-    """
-    Find elements which are referencing specified id (resource or tag).
-
-    element -- any element within CIB tree
-    referenced_id -- id which references should be found
-    """
-    return cast(
-        list[_Element],
-        _get_configuration(element).xpath(
-            _ELEMENTS_WITH_IDREF_WITHOUT_ID_XPATH,
-            referenced_id=referenced_id,
-        ),
-    )
-
-
 def find_elements_referencing_id(
     element: _Element,
     referenced_id: str,
@@ -625,14 +606,70 @@ def find_elements_referencing_id(
     )
 
 
+def find_location_constraints_referencing_node_name(
+    element: _Element, node_name: str
+) -> list[_Element]:
+    """
+    Find location constraints which are referencing specified node name.
+
+    element -- any element within CIB tree
+    node_name -- name of the node which references should be found
+    """
+    return cast(
+        list[_Element],
+        _get_configuration(element).xpath(
+            "./constraints/rsc_location[@node=$node_name]", node_name=node_name
+        ),
+    )
+
+
 def remove_element_by_id(cib: _Element, element_id: str) -> None:
     """
     Remove element with specified id from cib element.
     """
-    for ref_el in _find_elements_without_id_referencing_id(cib, element_id):
-        remove_one_element(ref_el)
-
     try:
         remove_one_element(get_element_by_id(cib, element_id))
     except ElementNotFound:
         pass
+
+
+def multivalue_attr_contains_value(
+    element: _Element, attr_name: str, value: str
+) -> bool:
+    """
+    Return whether attribute, that can contain multiple comma separated values,
+    contains specified value
+
+    element -- any element
+    attribute_name -- name of the multivalue attribute
+    value -- value that should be present in the attribute
+    """
+    return value in str(element.attrib[attr_name]).split(",")
+
+
+def multivalue_attr_has_any_values(element: _Element, attr_name: str) -> bool:
+    """
+    Return whether attribute, that can contain multiple comma separated values,
+    contains any value
+
+    element -- any element
+    attribute_name -- name of the multivalue attribute
+    """
+    return element.attrib[attr_name] != ""
+
+
+def multivalue_attr_delete_value(
+    element: _Element, attr_name: str, value: str
+) -> None:
+    """
+    Remove value from attribute, that can contain multiple comma separated
+    values.
+
+    element -- any element
+    attribute_name -- name of the multivalue attribute
+    value -- value to remove
+    """
+    new_attribute_value = [
+        val for val in str(element.attrib[attr_name]).split(",") if val != value
+    ]
+    element.set(attr_name, ",".join(new_attribute_value))
