@@ -2,10 +2,14 @@ import base64
 import os.path
 from functools import partial
 from typing import (
+    Collection,
+    Mapping,
     Optional,
     cast,
 )
 
+from lxml.etree import _Element
+
 from pcs import settings
 from pcs.common import (
     file_type_codes,
@@ -23,6 +27,7 @@ from pcs.common.reports.item import (
 )
 from pcs.common.services.errors import ManageServiceError
 from pcs.common.str_tools import join_multilines
+from pcs.common.types import StringSequence
 from pcs.lib import (
     tools,
     validate,
@@ -34,6 +39,12 @@ from pcs.lib.booth import (
     resource,
     status,
 )
+from pcs.lib.booth.cib import get_ticket_names as get_cib_ticket_names
+from pcs.lib.booth.env import BoothEnv
+from pcs.lib.cib.remove_elements import (
+    ElementsToRemove,
+    remove_specified_elements,
+)
 from pcs.lib.cib.resource import (
     group,
     hierarchy,
@@ -43,6 +54,7 @@ from pcs.lib.cib.tools import (
     IdProvider,
     get_resources,
 )
+from pcs.lib.commands.cib import _stop_resources_wait
 from pcs.lib.communication.booth import (
     BoothGetConfig,
     BoothSendConfig,
@@ -50,6 +62,7 @@ from pcs.lib.communication.booth import (
 from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
+from pcs.lib.external import CommandRunner
 from pcs.lib.file.instance import FileInstance
 from pcs.lib.file.raw_file import (
     GhostFile,
@@ -58,6 +71,13 @@ from pcs.lib.file.raw_file import (
 )
 from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.node import get_existing_nodes_names
+from pcs.lib.pacemaker.live import (
+    has_cib_xml,
+    resource_restart,
+)
+from pcs.lib.pacemaker.live import ticket_cleanup as live_ticket_cleanup
+from pcs.lib.pacemaker.live import ticket_standby as live_ticket_standby
+from pcs.lib.pacemaker.live import ticket_unstandby as live_ticket_unstandby
 from pcs.lib.resource_agent import (
     ResourceAgentError,
     ResourceAgentFacade,
@@ -75,19 +95,19 @@ from pcs.lib.services import (
 
 def config_setup(
     env: LibraryEnvironment,
-    site_list,
-    arbitrator_list,
-    instance_name=None,
-    overwrite_existing=False,
-):
+    site_list: StringSequence,
+    arbitrator_list: StringSequence,
+    instance_name: Optional[str] = None,
+    overwrite_existing: bool = False,
+) -> None:
     """
     create booth configuration
 
     env
-    list site_list -- site addresses of multisite
-    list arbitrator_list -- arbitrator addresses of multisite
-    string instance_name -- booth instance name
-    bool overwrite_existing -- allow overwriting existing files
+    site_list -- site addresses of multisite
+    arbitrator_list -- arbitrator addresses of multisite
+    instance_name -- booth instance name
+    overwrite_existing -- allow overwriting existing files
     """
     instance_name = instance_name or constants.DEFAULT_INSTANCE_NAME
     report_processor = env.report_processor
@@ -165,20 +185,30 @@ def config_destroy(
     found_instance_name = booth_env.instance_name
     _ensure_live_env(env, booth_env)
 
-    booth_resource_list = resource.find_for_config(
-        get_resources(env.get_cib()),
-        booth_env.config_path,
-    )
-    if booth_resource_list:
-        report_processor.report(
-            ReportItem.error(
-                reports.messages.BoothConfigIsUsed(
-                    found_instance_name,
-                    reports.const.BOOTH_CONFIG_USED_IN_CLUSTER_RESOURCE,
-                    resource_name=str(booth_resource_list[0].get("id", "")),
+    if (
+        has_cib_xml()
+        or env.service_manager.is_running("pacemaker")
+        or env.service_manager.is_running("pacemaker_remoted")
+    ):
+        # To allow destroying booth config on arbitrators, only check CIB if:
+        # * pacemaker is running and therefore we are able to get CIB
+        # * CIB is stored on disk - pcmk is not running but the node is in a
+        #   cluster (don't checking corosync to cover remote and guest nodes)
+        # If CIB cannot be loaded in either case, fail with an error.
+        booth_resource_list = resource.find_for_config(
+            get_resources(env.get_cib()),
+            booth_env.config_path,
+        )
+        if booth_resource_list:
+            report_processor.report(
+                ReportItem.error(
+                    reports.messages.BoothConfigIsUsed(
+                        found_instance_name,
+                        reports.const.BOOTH_CONFIG_USED_IN_CLUSTER_RESOURCE,
+                        resource_name=str(booth_resource_list[0].get("id", "")),
+                    )
                 )
             )
-        )
     # Only systemd is currently supported. Initd does not supports multiple
     # instances (here specified by name)
     if is_systemd(env.service_manager):
@@ -271,7 +301,7 @@ def config_destroy(
 
 # TODO: remove once settings booth_enable_autfile_(set|unset)_enabled are removed
 def _config_set_enable_authfile(
-    env: LibraryEnvironment, value: bool, instance_name=None
+    env: LibraryEnvironment, value: bool, instance_name: Optional[str] = None
 ) -> None:
     report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
@@ -296,24 +326,28 @@ def _config_set_enable_authfile(
 
 
 def config_set_enable_authfile(
-    env: LibraryEnvironment, instance_name=None
+    env: LibraryEnvironment, instance_name: Optional[str] = None
 ) -> None:
     _config_set_enable_authfile(env, True, instance_name=instance_name)
 
 
 def config_unset_enable_authfile(
-    env: LibraryEnvironment, instance_name=None
+    env: LibraryEnvironment, instance_name: Optional[str] = None
 ) -> None:
     _config_set_enable_authfile(env, False, instance_name=instance_name)
 
 
-def config_text(env: LibraryEnvironment, instance_name=None, node_name=None):
+def config_text(
+    env: LibraryEnvironment,
+    instance_name: Optional[str] = None,
+    node_name: Optional[str] = None,
+) -> str:
     """
     get configuration in raw format
 
     env
-    string instance_name -- booth instance name
-    string node_name -- get the config from specified node or local host if None
+    instance_name -- booth instance name
+    node_name -- get the config from specified node or local host if None
     """
     report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
@@ -334,7 +368,7 @@ def config_text(env: LibraryEnvironment, instance_name=None, node_name=None):
 
     com_cmd = BoothGetConfig(env.report_processor, instance_name)
     com_cmd.set_targets(
-        [env.get_node_target_factory().get_target_from_hostname(node_name)]
+        [env.get_node_target_factory().get_target_from_hostname(str(node_name))]
     )
     remote_data = run_and_raise(env.get_node_communicator(), com_cmd)[0][1]
     try:
@@ -343,25 +377,27 @@ def config_text(env: LibraryEnvironment, instance_name=None, node_name=None):
         return remote_data["config"]["data"].encode("utf-8")
     except KeyError as e:
         raise LibraryError(
-            ReportItem.error(reports.messages.InvalidResponseFormat(node_name))
+            ReportItem.error(
+                reports.messages.InvalidResponseFormat(str(node_name))
+            )
         ) from e
 
 
 def config_ticket_add(
     env: LibraryEnvironment,
-    ticket_name,
-    options,
-    instance_name=None,
-    allow_unknown_options=False,
-):
+    ticket_name: str,
+    options: validate.TypeOptionMap,
+    instance_name: Optional[str] = None,
+    allow_unknown_options: bool = False,
+) -> None:
     """
     add a ticket to booth configuration
 
     env
-    string ticket_name -- the name of the ticket to be created
-    dict options -- options for the ticket
-    string instance_name -- booth instance name
-    bool allow_unknown_options -- allow using options unknown to pcs
+    ticket_name -- the name of the ticket to be created
+    options -- options for the ticket
+    instance_name -- booth instance name
+    allow_unknown_options -- allow using options unknown to pcs
     """
     report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
@@ -396,15 +432,15 @@ def config_ticket_add(
 
 def config_ticket_remove(
     env: LibraryEnvironment,
-    ticket_name,
-    instance_name=None,
-):
+    ticket_name: str,
+    instance_name: Optional[str] = None,
+) -> None:
     """
     remove a ticket from booth configuration
 
     env
-    string ticket_name -- the name of the ticket to be removed
-    string instance_name -- booth instance name
+    ticket_name -- the name of the ticket to be removed
+    instance_name -- booth instance name
     """
     report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
@@ -432,7 +468,7 @@ def create_in_cluster(
     ip: str,
     instance_name: Optional[str] = None,
     allow_absent_resource_agent: bool = False,
-):
+) -> None:
     """
     Create group with ip resource and booth resource
 
@@ -516,76 +552,92 @@ def create_in_cluster(
 
 def remove_from_cluster(
     env: LibraryEnvironment,
-    resource_remove,
-    instance_name=None,
-    allow_remove_multiple=False,
-):
+    instance_name: Optional[str] = None,
+    force_flags: Collection[reports.types.ForceCode] = (),
+) -> None:
     """
     Remove group with ip resource and booth resource
 
     env -- provides all for communication with externals
-    function resource_remove -- provisional hack til resources are moved to lib
-    string instance_name -- booth instance name
-    bool allow_remove_multiple -- remove all resources if more than one found
+    instance_name -- booth instance name
+    force_flags -- list of flags codes
     """
-    # TODO resource_remove is provisional hack til resources are moved to lib
     report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
     # This command does not work with booth config files at all, let's reject
     # them then.
     _ensure_live_booth_env(booth_env)
 
-    resource.get_remover(resource_remove)(
+    cib = env.get_cib()
+    booth_elements_to_remove = resource.find_elements_to_remove(
         _find_resource_elements_for_operation(
             report_processor,
-            get_resources(env.get_cib()),
+            get_resources(cib),
             booth_env,
-            allow_remove_multiple,
+            allow_multiple=reports.codes.FORCE in force_flags,
         )
     )
 
+    resource_ids = [str(el.attrib["id"]) for el in booth_elements_to_remove]
+    elements_to_remove = ElementsToRemove(cib, resource_ids)
+
+    report_processor.report(
+        reports.ReportItem.info(
+            reports.messages.CibRemoveResources(resource_ids)
+        )
+    )
+    report_processor.report_list(
+        elements_to_remove.dependant_elements.to_reports()
+    )
+    report_processor.report_list(
+        elements_to_remove.element_references.to_reports()
+    )
+
+    cib = _stop_resources_wait(
+        env, cib, elements_to_remove.resources_to_remove, force_flags
+    )
+
+    remove_specified_elements(cib, elements_to_remove)
+    env.push_cib()
+
 
 def restart(
     env: LibraryEnvironment,
-    resource_restart,
-    instance_name=None,
-    allow_multiple=False,
-):
+    instance_name: Optional[str] = None,
+    allow_multiple: bool = False,
+) -> None:
     """
     Restart group with ip resource and booth resource
 
     env -- provides all for communication with externals
-    function resource_restart -- provisional hack til resources are moved to lib
-    string instance_name -- booth instance name
-    bool allow_remove_multiple -- remove all resources if more than one found
+    instance_name -- booth instance name
+    allow_multiple -- restart all resources if more than one found
     """
-    # TODO resource_remove is provisional hack til resources are moved to lib
-    report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
     _ensure_live_env(env, booth_env)
 
     for booth_element in _find_resource_elements_for_operation(
-        report_processor,
+        env.report_processor,
         get_resources(env.get_cib()),
         booth_env,
         allow_multiple,
     ):
-        resource_restart([booth_element.attrib["id"]])
+        resource_restart(env.cmd_runner(), str(booth_element.attrib["id"]))
 
 
 def ticket_grant(
     env: LibraryEnvironment,
-    ticket_name,
-    site_ip=None,
-    instance_name=None,
-):
+    ticket_name: str,
+    site_ip: Optional[str] = None,
+    instance_name: Optional[str] = None,
+) -> None:
     """
     Grant a ticket to the site specified by site_ip
 
     env
-    string ticket_name -- the name of the ticket to be granted
-    string site_ip -- IP of the site to grant the ticket to, None for local
-    string instance_name -- booth instance name
+    ticket_name -- the name of the ticket to be granted
+    site_ip -- IP of the site to grant the ticket to, None for local
+    instance_name -- booth instance name
     """
     return _ticket_operation(
         "grant",
@@ -598,17 +650,17 @@ def ticket_grant(
 
 def ticket_revoke(
     env: LibraryEnvironment,
-    ticket_name,
-    site_ip=None,
-    instance_name=None,
-):
+    ticket_name: str,
+    site_ip: Optional[str] = None,
+    instance_name: Optional[str] = None,
+) -> None:
     """
     Revoke a ticket from the site specified by site_ip
 
     env
-    string ticket_name -- the name of the ticket to be revoked
-    string site_ip -- IP of the site to revoke the ticket from, None for local
-    string instance_name -- booth instance name
+    ticket_name -- the name of the ticket to be revoked
+    site_ip -- IP of the site to revoke the ticket from, None for local
+    instance_name -- booth instance name
     """
     return _ticket_operation(
         "revoke",
@@ -620,8 +672,12 @@ def ticket_revoke(
 
 
 def _ticket_operation(
-    operation, env: LibraryEnvironment, ticket_name, site_ip, instance_name
-):
+    operation: str,
+    env: LibraryEnvironment,
+    ticket_name: str,
+    site_ip: Optional[str],
+    instance_name: Optional[str],
+) -> None:
     booth_env = env.get_booth_env(instance_name)
     _ensure_live_env(env, booth_env)
 
@@ -660,16 +716,149 @@ def _ticket_operation(
         )
 
 
+def ticket_cleanup(env: LibraryEnvironment, ticket_name: str) -> None:
+    """
+    Remove specified booth ticket from CIB on local site
+
+    ticket_name -- name of the ticket to remove
+    """
+    _ensure_live_cib(env)
+
+    report_processor = env.report_processor
+
+    if report_processor.report_list(
+        _validate_ticket_in_cib(env.get_cib(), ticket_name)
+    ).has_errors:
+        raise LibraryError()
+
+    cmd_runner = env.cmd_runner()
+
+    # standby the ticket first, so the node is not fenced if ticket-loss
+    # policy is set to 'fence' in the ticket constraint
+    report_processor.report_list(_ticket_standby(cmd_runner, ticket_name))
+    if report_processor.has_errors:
+        raise LibraryError()
+
+    report_processor.report(
+        reports.ReportItem.info(
+            reports.messages.BoothTicketCleanup(ticket_name)
+        )
+    )
+    stdout, stderr, retval = live_ticket_cleanup(cmd_runner, ticket_name)
+    if retval != 0:
+        report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.BoothTicketOperationFailed(
+                    "cleanup",
+                    join_multilines([stderr, stdout]),
+                    None,
+                    ticket_name,
+                )
+            )
+        )
+
+    if report_processor.has_errors:
+        raise LibraryError()
+
+
+def ticket_standby(env: LibraryEnvironment, ticket_name: str) -> None:
+    """
+    Change state of the ticket to standby
+
+    ticket_name -- name of the ticket
+    """
+    _ensure_live_cib(env)
+    if env.report_processor.report_list(
+        _validate_ticket_in_cib(env.get_cib(), ticket_name)
+    ).has_errors:
+        raise LibraryError()
+
+    if env.report_processor.report_list(
+        _ticket_standby(env.cmd_runner(), ticket_name)
+    ).has_errors:
+        raise LibraryError()
+
+
+def _ticket_standby(
+    cmd_runner: CommandRunner, ticket: str
+) -> reports.ReportItemList:
+    report_list = [
+        reports.ReportItem.info(
+            reports.messages.BoothTicketChangingState(ticket, "standby")
+        )
+    ]
+
+    stdout, stderr, retval = live_ticket_standby(cmd_runner, ticket)
+    if retval != 0:
+        report_list.append(
+            reports.ReportItem.error(
+                reports.messages.BoothTicketOperationFailed(
+                    "standby", join_multilines([stderr, stdout]), None, ticket
+                )
+            )
+        )
+
+    return report_list
+
+
+def ticket_unstandby(env: LibraryEnvironment, ticket_name: str) -> None:
+    """
+    Change state of the ticket to active
+
+    ticket_name -- name of the ticket
+    """
+    _ensure_live_cib(env)
+    if env.report_processor.report_list(
+        _validate_ticket_in_cib(env.get_cib(), ticket_name)
+    ).has_errors:
+        raise LibraryError()
+
+    env.report_processor.report(
+        reports.ReportItem.info(
+            reports.messages.BoothTicketChangingState(ticket_name, "active")
+        )
+    )
+    stdout, stderr, retval = live_ticket_unstandby(
+        env.cmd_runner(), ticket_name
+    )
+    if retval != 0:
+        env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.BoothTicketOperationFailed(
+                    "unstandby",
+                    join_multilines([stderr, stdout]),
+                    None,
+                    ticket_name,
+                )
+            )
+        )
+    if env.report_processor.has_errors:
+        raise LibraryError()
+
+
+def _validate_ticket_in_cib(
+    cib: _Element, ticket_name: str
+) -> reports.ReportItemList:
+    if ticket_name not in set(get_cib_ticket_names(cib)):
+        return [
+            reports.ReportItem.error(
+                reports.messages.BoothTicketNotInCib(ticket_name)
+            )
+        ]
+
+    return []
+
+
 def config_sync(
     env: LibraryEnvironment,
-    instance_name=None,
-    skip_offline_nodes=False,
-):
+    instance_name: Optional[str] = None,
+    skip_offline_nodes: bool = False,
+) -> None:
     """
     Send specified local booth configuration to all nodes in the local cluster.
 
     env
-    string instance_name -- booth instance name
+    instance_name -- booth instance name
     skip_offline_nodes -- if True offline nodes will be skipped
     """
     report_processor = env.report_processor
@@ -732,12 +921,14 @@ def config_sync(
     run_and_raise(env.get_node_communicator(), com_cmd)
 
 
-def enable_booth(env: LibraryEnvironment, instance_name=None):
+def enable_booth(
+    env: LibraryEnvironment, instance_name: Optional[str] = None
+) -> None:
     """
     Enable specified instance of booth service, systemd systems supported only.
 
     env
-    string instance_name -- booth instance name
+    instance_name -- booth instance name
     """
     ensure_is_systemd(env.service_manager)
     booth_env = env.get_booth_env(instance_name)
@@ -759,12 +950,14 @@ def enable_booth(env: LibraryEnvironment, instance_name=None):
     )
 
 
-def disable_booth(env: LibraryEnvironment, instance_name=None):
+def disable_booth(
+    env: LibraryEnvironment, instance_name: Optional[str] = None
+) -> None:
     """
     Disable specified instance of booth service, systemd systems supported only.
 
     env
-    string instance_name -- booth instance name
+    instance_name -- booth instance name
     """
     ensure_is_systemd(env.service_manager)
     booth_env = env.get_booth_env(instance_name)
@@ -786,14 +979,16 @@ def disable_booth(env: LibraryEnvironment, instance_name=None):
     )
 
 
-def start_booth(env: LibraryEnvironment, instance_name=None):
+def start_booth(
+    env: LibraryEnvironment, instance_name: Optional[str] = None
+) -> None:
     """
     Start specified instance of booth service, systemd systems supported only.
         On non-systemd systems it can be run like this:
         BOOTH_CONF_FILE=<booth-file-path> /etc/initd/booth-arbitrator
 
     env
-    string instance_name -- booth instance name
+    instance_name -- booth instance name
     """
     ensure_is_systemd(env.service_manager)
     booth_env = env.get_booth_env(instance_name)
@@ -815,12 +1010,14 @@ def start_booth(env: LibraryEnvironment, instance_name=None):
     )
 
 
-def stop_booth(env: LibraryEnvironment, instance_name=None):
+def stop_booth(
+    env: LibraryEnvironment, instance_name: Optional[str] = None
+) -> None:
     """
     Stop specified instance of booth service, systemd systems supported only.
 
     env
-    string instance_name -- booth instance name
+    instance_name -- booth instance name
     """
     ensure_is_systemd(env.service_manager)
     booth_env = env.get_booth_env(instance_name)
@@ -842,14 +1039,16 @@ def stop_booth(env: LibraryEnvironment, instance_name=None):
     )
 
 
-def pull_config(env: LibraryEnvironment, node_name, instance_name=None):
+def pull_config(
+    env: LibraryEnvironment, node_name: str, instance_name: Optional[str] = None
+) -> None:
     """
     Get config from specified node and save it on local system. It will
     rewrite existing files.
 
     env
-    string node_name -- name of the node from which the config should be fetched
-    string instance_name -- booth instance name
+    node_name -- name of the node from which the config should be fetched
+    instance_name -- booth instance name
     """
     report_processor = env.report_processor
     booth_env = env.get_booth_env(instance_name)
@@ -910,12 +1109,14 @@ def pull_config(env: LibraryEnvironment, node_name, instance_name=None):
         raise LibraryError()
 
 
-def get_status(env: LibraryEnvironment, instance_name=None):
+def get_status(
+    env: LibraryEnvironment, instance_name: Optional[str] = None
+) -> Mapping[str, str]:
     """
     get booth status info
 
     env
-    string instance_name -- booth instance name
+    instance_name -- booth instance name
     """
     booth_env = env.get_booth_env(instance_name)
     _ensure_live_env(env, booth_env)
@@ -934,10 +1135,10 @@ def get_status(env: LibraryEnvironment, instance_name=None):
 
 def _find_resource_elements_for_operation(
     report_processor: ReportProcessor,
-    resources_section,
-    booth_env,
-    allow_multiple,
-):
+    resources_section: _Element,
+    booth_env: BoothEnv,
+    allow_multiple: bool,
+) -> list[_Element]:
     booth_element_list = resource.find_for_config(
         resources_section,
         booth_env.config_path,
@@ -967,7 +1168,7 @@ def _find_resource_elements_for_operation(
     return booth_element_list
 
 
-def _ensure_live_booth_env(booth_env):
+def _ensure_live_booth_env(booth_env: BoothEnv) -> None:
     if booth_env.ghost_file_codes:
         raise LibraryError(
             ReportItem.error(
@@ -978,7 +1179,18 @@ def _ensure_live_booth_env(booth_env):
         )
 
 
-def _ensure_live_env(env: LibraryEnvironment, booth_env):
+def _ensure_live_cib(env: LibraryEnvironment) -> None:
+    if not env.is_cib_live:
+        env.report_processor.report(
+            ReportItem.error(
+                reports.messages.LiveEnvironmentRequired([file_type_codes.CIB])
+            )
+        )
+    if env.report_processor.has_errors:
+        raise LibraryError()
+
+
+def _ensure_live_env(env: LibraryEnvironment, booth_env: BoothEnv) -> None:
     not_live = (
         booth_env.ghost_file_codes
         +
