@@ -31,7 +31,7 @@ from pcs.common.reports.item import (
     ReportItemList,
 )
 from pcs.common.str_tools import join_multilines
-from pcs.common.tools import format_environment_error
+from pcs.common.tools import format_os_error
 from pcs.common.types import (
     CorosyncTransportType,
     UnknownCorosyncTransportTypeException,
@@ -45,10 +45,6 @@ from pcs.lib.booth import sync as booth_sync
 from pcs.lib.cib import fencing_topology
 from pcs.lib.cib.resource.guest_node import find_node_list as get_guest_nodes
 from pcs.lib.cib.resource.remote_node import find_node_list as get_remote_nodes
-from pcs.lib.cib.tools import (
-    get_fencing_topology,
-    get_resources,
-)
 from pcs.lib.communication import cluster
 from pcs.lib.communication.corosync import (
     CheckCorosyncOffline,
@@ -179,8 +175,7 @@ def verify(env: LibraryEnvironment, verbose=False):
     cib = get_cib(cib_xml)
     env.report_processor.report_list(
         fencing_topology.verify(
-            get_fencing_topology(cib),
-            get_resources(cib),
+            cib,
             ClusterState(env.get_cluster_state()).node_section.nodes,
         )
     )
@@ -207,6 +202,7 @@ def setup(
     force_flags: Collection[reports.types.ForceCode] = (),
 ):
     # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-positional-arguments
     # pylint: disable=too-many-locals
     # pylint: disable=too-many-statements
     """
@@ -498,6 +494,7 @@ def setup_local(
     """
     # pylint: disable=too-many-arguments
     # pylint: disable=too-many-locals
+    # pylint: disable=too-many-positional-arguments
     force = report_codes.FORCE in force_flags
 
     transport_type = transport_type or "knet"
@@ -587,6 +584,7 @@ def _validate_create_corosync_conf(
     force: bool,
 ) -> reports.ReportItemList:
     # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-positional-arguments
 
     # Get IP version for node addresses validation. Defaults taken from man
     # corosync.conf
@@ -647,6 +645,7 @@ def _create_corosync_conf(
     no_cluster_uuid: bool,
 ) -> config_facade.ConfigFacade:
     # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-positional-arguments
     corosync_conf = config_facade.ConfigFacade.create(
         cluster_name, nodes, transport_type
     )
@@ -1226,14 +1225,14 @@ def add_nodes(
                         corosync_authkey_file.read()
                     )
                 )
-        except EnvironmentError as e:
+        except OSError as e:
             report_processor.report(
                 ReportItem(
                     severity,
                     reports.messages.FileIoError(
                         file_type_codes.COROSYNC_AUTHKEY,
                         RawFileError.ACTION_READ,
-                        format_environment_error(e),
+                        format_os_error(e),
                         file_path=settings.corosync_authkey_file,
                     ),
                 )
@@ -1249,14 +1248,14 @@ def add_nodes(
                         pcmk_authkey_file.read()
                     )
                 )
-        except EnvironmentError as e:
+        except OSError as e:
             report_processor.report(
                 ReportItem(
                     severity,
                     reports.messages.FileIoError(
                         file_type_codes.PACEMAKER_AUTHKEY,
                         RawFileError.ACTION_READ,
-                        format_environment_error(e),
+                        format_os_error(e),
                         file_path=settings.pacemaker_authkey_file,
                     ),
                 )
@@ -1272,14 +1271,14 @@ def add_nodes(
                         pcs_dr_config_file.read()
                     )
                 )
-        except EnvironmentError as e:
+        except OSError as e:
             report_processor.report(
                 ReportItem(
                     severity,
                     reports.messages.FileIoError(
                         file_type_codes.PCS_DR_CONFIG,
                         RawFileError.ACTION_READ,
-                        format_environment_error(e),
+                        format_os_error(e),
                         file_path=settings.pcsd_dr_config_location,
                     ),
                 )
@@ -1298,14 +1297,14 @@ def add_nodes(
                         pcs_settings_conf_file.read()
                     )
                 )
-        except EnvironmentError as e:
+        except OSError as e:
             report_processor.report(
                 ReportItem(
                     severity,
                     reports.messages.FileIoError(
                         file_type_codes.PCS_SETTINGS_CONF,
                         RawFileError.ACTION_READ,
-                        format_environment_error(e),
+                        format_os_error(e),
                         file_path=settings.pcsd_settings_conf_location,
                     ),
                 )
@@ -1335,13 +1334,13 @@ def add_nodes(
         try:
             with open(settings.pcsd_cert_location, "r") as file:
                 ssl_cert = file.read()
-        except EnvironmentError as e:
+        except OSError as e:
             report_processor.report(
                 ReportItem.error(
                     reports.messages.FileIoError(
                         file_type_codes.PCSD_SSL_CERT,
                         RawFileError.ACTION_READ,
-                        format_environment_error(e),
+                        format_os_error(e),
                         file_path=settings.pcsd_cert_location,
                     )
                 )
@@ -1349,13 +1348,13 @@ def add_nodes(
         try:
             with open(settings.pcsd_key_location, "r") as file:
                 ssl_key = file.read()
-        except EnvironmentError as e:
+        except OSError as e:
             report_processor.report(
                 ReportItem.error(
                     reports.messages.FileIoError(
                         file_type_codes.PCSD_SSL_KEY,
                         RawFileError.ACTION_READ,
-                        format_environment_error(e),
+                        format_os_error(e),
                         file_path=settings.pcsd_key_location,
                     )
                 )
@@ -1616,6 +1615,7 @@ def _get_addrs_defaulter(
         if "name" not in node:
             return []
         address_for_use = None
+        address_source = None
         target = targets_dict.get(node["name"])
         if target:
             address_for_use = target.first_addr
@@ -1679,13 +1679,13 @@ def _is_ssl_cert_sync_enabled(report_processor: ReportProcessor):
                     cfg.get("PCSD_SSL_CERT_SYNC_ENABLED", "false").lower()
                     == "true"
                 )
-    except EnvironmentError as e:
+    except OSError as e:
         report_processor.report(
             ReportItem.error(
                 reports.messages.FileIoError(
                     file_type_codes.PCSD_ENVIRONMENT_CONFIG,
                     RawFileError.ACTION_READ,
-                    format_environment_error(e),
+                    format_os_error(e),
                     file_path=settings.pcsd_config,
                 )
             )
@@ -2304,3 +2304,14 @@ def generate_cluster_uuid_local(
         raise LibraryError()
 
     return corosync_conf_instance.facade_to_raw(corosync_conf)
+
+
+def wait_for_pcmk_idle(env: LibraryEnvironment, wait_value: WaitType) -> None:
+    """
+    Wait for the cluster to settle into stable state.
+
+    env
+    wait_value -- value describing the timeout the command
+    """
+    timeout = env.ensure_wait_satisfiable(wait_value)
+    env.wait_for_idle(timeout)
