@@ -66,6 +66,7 @@ from pcs.lib.pacemaker.live import (
     push_cib_diff_xml,
     resource_ban,
     resource_move,
+    resource_restart,
     resource_unmove_unban,
     simulate_cib,
 )
@@ -101,7 +102,7 @@ from pcs.lib.xml_tools import (
 
 @contextmanager
 def resource_environment(
-    env,
+    env: LibraryEnvironment,
     wait: WaitType = False,
     wait_for_resource_ids=None,
     resource_state_reporter=info_resource_state,
@@ -177,6 +178,17 @@ def _get_agent_facade(
                     )
                 )
             )
+        if split_name.standard in ("nagios", "upstart"):
+            # TODO deprecated in pacemaker 2, to be removed in pacemaker 3
+            # added to pcs after 0.11.7
+            report_processor.report(
+                reports.ReportItem.deprecation(
+                    reports.messages.DeprecatedOptionValue(
+                        "standard", split_name.standard
+                    )
+                )
+            )
+
         return factory.facade_from_parsed_name(split_name)
     except (UnableToGetAgentMetadata, UnsupportedOcfVersion) as e:
         if allow_absent_agent:
@@ -355,6 +367,7 @@ def create(
     operation_list: List[Mapping[str, str]],
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
+    *,
     allow_absent_agent: bool = False,
     allow_invalid_operation: bool = False,
     allow_invalid_instance_attributes: bool = False,
@@ -462,6 +475,7 @@ def create_as_clone(
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
     clone_meta_options: Mapping[str, str],
+    *,
     clone_id: Optional[str] = None,
     allow_absent_agent: bool = False,
     allow_invalid_operation: bool = False,
@@ -611,6 +625,7 @@ def create_in_group(
     operation_list: List[Mapping[str, str]],
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
+    *,
     allow_absent_agent: bool = False,
     allow_invalid_operation: bool = False,
     allow_invalid_instance_attributes: bool = False,
@@ -757,6 +772,7 @@ def create_into_bundle(
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
     bundle_id: str,
+    *,
     allow_absent_agent: bool = False,
     allow_invalid_operation: bool = False,
     allow_invalid_instance_attributes: bool = False,
@@ -871,6 +887,7 @@ def bundle_create(
     env,
     bundle_id,
     container_type,
+    *,
     container_options=None,
     network_options=None,
     port_map=None,
@@ -949,6 +966,7 @@ def bundle_create(
 def bundle_reset(
     env,
     bundle_id,
+    *,
     container_options=None,
     network_options=None,
     port_map=None,
@@ -1033,6 +1051,7 @@ def bundle_reset(
 def bundle_update(
     env,
     bundle_id,
+    *,
     container_options=None,
     network_options=None,
     port_map_add=None,
@@ -2436,16 +2455,13 @@ def _find_resources_expand_tags(
     rsc_or_tag_el_list, report_list = resource.common.find_resources(
         cib,
         resource_or_tag_ids,
-        resource_tags=resource.common.ALL_RESOURCE_XML_TAGS
-        + [cib_const.TAG_TAG],
+        resource_tags=cib_const.TAG_LIST_RESOURCE | {cib_const.TAG_TAG},
     )
 
     resource_set = set()
     for el in rsc_or_tag_el_list:
         resource_set.update(
-            expand_tag(
-                el, only_expand_types=resource.common.ALL_RESOURCE_XML_TAGS
-            )
+            expand_tag(el, only_expand_types=cib_const.TAG_LIST_RESOURCE)
         )
     if not additional_search:
         return list(resource_set), report_list
@@ -2534,3 +2550,84 @@ def get_configured_resources(env: LibraryEnvironment) -> CibResourcesDto:
         ],
         bundles=bundles,
     )
+
+
+def restart(
+    env: LibraryEnvironment,
+    resource_id: str,
+    node: Optional[str] = None,
+    timeout: Optional[str] = None,
+) -> None:
+    """
+    Restart a resource
+
+    resource_id -- id of the resource to be restarted
+    node -- name of the node to limit the restart to
+    timeout -- abort if the command doesn't finish in this time (integer + unit)
+    """
+    cib = env.get_cib()
+    try:
+        resource_el = get_element_by_id(cib, resource_id)
+    except ElementNotFound as e:
+        env.report_processor.report(
+            ReportItem.error(
+                reports.messages.IdNotFound(
+                    resource_id, expected_types=["resource"]
+                )
+            )
+        )
+        raise LibraryError() from e
+    if not resource.common.is_resource(resource_el):
+        env.report_processor.report(
+            ReportItem.error(
+                reports.messages.IdBelongsToUnexpectedType(
+                    resource_id,
+                    expected_types=["resource"],
+                    current_type=resource_el.tag,
+                )
+            )
+        )
+        raise LibraryError()
+
+    parent_resource_el = resource.clone.get_parent_any_clone(resource_el)
+    if parent_resource_el is None:
+        parent_resource_el = resource.bundle.get_parent_bundle(resource_el)
+    if parent_resource_el is not None:
+        env.report_processor.report(
+            reports.ReportItem.warning(
+                reports.messages.ResourceRestartUsingParentRersource(
+                    str(resource_el.attrib["id"]),
+                    str(parent_resource_el.attrib["id"]),
+                )
+            )
+        )
+        resource_el = parent_resource_el
+
+    if node and not (
+        resource.clone.is_any_clone(resource_el)
+        or resource.bundle.is_bundle(resource_el)
+    ):
+        env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.ResourceRestartNodeIsForMultiinstanceOnly(
+                    str(resource_el.attrib["id"]),
+                    resource_el.tag,
+                    node,
+                )
+            )
+        )
+
+    if timeout is not None:
+        env.report_processor.report_list(
+            ValueTimeInterval("timeout").validate({"timeout": timeout})
+        )
+
+    if env.report_processor.has_errors:
+        raise LibraryError()
+
+    resource_restart(
+        env.cmd_runner(),
+        str(resource_el.attrib["id"]),
+        node=node,
+        timeout=timeout,
+    )
