@@ -17,6 +17,7 @@ from pcs.common.node_communicator import Communicator
 from pcs.common.reports import ReportProcessor
 from pcs.common.reports.item import ReportItem
 from pcs.common.services.interfaces import ServiceManagerInterface
+from pcs.common.status_dto import ResourcesStatusDto
 from pcs.common.str_tools import (
     format_list,
     indent,
@@ -48,6 +49,11 @@ from pcs.lib.pacemaker.live import (
     get_cluster_status_xml_raw,
     get_ticket_status_text,
 )
+from pcs.lib.pacemaker.status import (
+    ClusterStatusParser,
+    ClusterStatusParsingError,
+    cluster_status_parsing_error_to_report,
+)
 from pcs.lib.resource_agent.const import STONITH_ACTION_REPLACED_BY
 from pcs.lib.sbd import get_sbd_service_name
 
@@ -69,6 +75,25 @@ def pacemaker_status_xml(env: LibraryEnvironment) -> str:
     raise LibraryError(output=stdout)
 
 
+def resources_status(env: LibraryEnvironment) -> ResourcesStatusDto:
+    """
+    Return pacemaker status of configured resources as DTO
+
+    env -- LibraryEnvironment
+    """
+    status_xml = env.get_cluster_state()
+
+    parser = ClusterStatusParser(status_xml)
+    try:
+        dto = parser.status_xml_to_dto()
+    except ClusterStatusParsingError as e:
+        raise LibraryError(cluster_status_parsing_error_to_report(e)) from e
+
+    env.report_processor.report_list(parser.get_warnings())
+
+    return dto
+
+
 def full_cluster_status_plaintext(
     env: LibraryEnvironment,
     hide_inactive_resources: bool = False,
