@@ -16,9 +16,11 @@ import xml.dom.minidom
 import xml.etree.ElementTree as ET
 from functools import lru_cache
 from io import BytesIO
+from textwrap import dedent
 from typing import (
     Any,
     Dict,
+    Optional,
     Tuple,
 )
 from urllib.parse import urlencode
@@ -221,6 +223,25 @@ def read_uid_gid_file(uidgid_filename):
     return uidgid
 
 
+def get_uidgid_file_content(
+    uid: Optional[str] = None, gid: Optional[str] = None
+) -> Optional[str]:
+    if not uid and not gid:
+        return None
+    uid_gid_lines = []
+    if uid:
+        uid_gid_lines.append(f"  uid: {uid}")
+    if gid:
+        uid_gid_lines.append(f"  gid: {gid}")
+    return dedent(
+        """\
+        uidgid {{
+        {uid_gid_keys}
+        }}
+        """
+    ).format(uid_gid_keys="\n".join(uid_gid_lines))
+
+
 def write_uid_gid_file(uid, gid):
     """
     Commandline options: no options
@@ -237,11 +258,12 @@ def write_uid_gid_file(uid, gid):
         counter = counter + 1
         uidgid_filename = orig_filename + "-" + str(counter)
 
-    data = "uidgid {\n  uid: %s\ngid: %s\n}\n" % (uid, gid)
-    with open(
-        os.path.join(settings.corosync_uidgid_dir, uidgid_filename), "w"
-    ) as uidgid_file:
-        uidgid_file.write(data)
+    data = get_uidgid_file_content(uid, gid)
+    if data:
+        with open(
+            os.path.join(settings.corosync_uidgid_dir, uidgid_filename), "w"
+        ) as uidgid_file:
+            uidgid_file.write(data)
 
 
 def find_uid_gid_files(uid, gid):
@@ -1157,19 +1179,6 @@ def parallel_for_nodes(action, node_list, *args, **kwargs):
     return node_errors
 
 
-# Check if something exists in the CIB
-def does_exist(xpath_query):
-    """
-    Commandline options:
-      * -f - CIB file
-    """
-    args = ["cibadmin", "-Q", "--xpath", xpath_query]
-    dummy_output, retval = run(args)
-    if retval != 0:
-        return False
-    return True
-
-
 def get_group_children(group_id):
     """
     Commandline options: no options
@@ -1342,16 +1351,6 @@ def dom_get_any_resource(dom, resource_id):
     )
 
 
-def is_stonith_resource(resource_id):
-    """
-    Commandline options:
-      * -f - CIB file
-    """
-    return does_exist(
-        "//primitive[@id='" + resource_id + "' and @class='stonith']"
-    )
-
-
 def dom_get_resource_clone(dom, resource_id):
     """
     Commandline options: no options
@@ -1523,9 +1522,11 @@ def dom_attrs_to_list(dom_el, with_id=False):
         "%s=%s"
         % (
             name,
-            value
-            if name != "role"
-            else common_pacemaker.role.get_value_primary(value.capitalize()),
+            (
+                value
+                if name != "role"
+                else common_pacemaker.role.get_value_primary(value.capitalize())
+            ),
         )
         for name, value in sorted(dom_el.attributes.items())
         if name != "id"
@@ -2245,6 +2246,7 @@ def tar_add_file_data(
     tarball,
     data,
     name,
+    *,
     mode=None,
     uid=None,
     gid=None,
@@ -2281,11 +2283,14 @@ def simulate_cib(cib_dom):
     Commandline options: no options
     """
     try:
-        with tempfile.NamedTemporaryFile(
-            mode="w+", suffix=".pcs"
-        ) as new_cib_file, tempfile.NamedTemporaryFile(
-            mode="w+", suffix=".pcs"
-        ) as transitions_file:
+        with (
+            tempfile.NamedTemporaryFile(
+                mode="w+", suffix=".pcs"
+            ) as new_cib_file,
+            tempfile.NamedTemporaryFile(
+                mode="w+", suffix=".pcs"
+            ) as transitions_file,
+        ):
             output, retval = run(
                 [
                     "crm_simulate",
