@@ -260,6 +260,21 @@ class DateInrangeExpression(TestCase):
         "weekyears",
         "moon",
     }
+    deprecation_reports = [
+        fixture.deprecation(
+            reports.codes.DEPRECATED_OPTION,
+            option_name=option,
+            replaced_by=[],
+            option_type="duration",
+        )
+        for option in (
+            "monthdays",
+            "weekdays",
+            "weekyears",
+            "moon",
+            "yearsdays",
+        )
+    ]
 
     def test_date_date_ok(self):
         # pylint: disable=no-self-use
@@ -296,7 +311,7 @@ class DateInrangeExpression(TestCase):
                     ],
                 ),
             ).get_reports(),
-            [],
+            [] + self.deprecation_reports,
         )
 
     def test_until_greater_than_since(self):
@@ -442,7 +457,8 @@ class DateInrangeExpression(TestCase):
                     reports.codes.RULE_EXPRESSION_OPTIONS_DUPLICATION,
                     duplicate_option_list=["hours"],
                 ),
-            ],
+            ]
+            + self.deprecation_reports,
         )
 
 
@@ -458,6 +474,20 @@ class DatespecExpression(TestCase):
         "weekyears",
         "moon",
     }
+    deprecation_reports = [
+        fixture.deprecation(
+            reports.codes.DEPRECATED_OPTION,
+            option_name="yearsdays",
+            replaced_by=[],
+            option_type="datespec",
+        ),
+        fixture.deprecation(
+            reports.codes.DEPRECATED_OPTION,
+            option_name="moon",
+            replaced_by=[],
+            option_type="datespec",
+        ),
+    ]
 
     def test_ok(self):
         assert_report_item_list_equal(
@@ -467,7 +497,7 @@ class DatespecExpression(TestCase):
                     [DatespecExpr([(name, "3") for name in self.part_list])],
                 ),
             ).get_reports(),
-            [],
+            [] + self.deprecation_reports,
         )
 
     def test_range_ok(self):
@@ -478,7 +508,7 @@ class DatespecExpression(TestCase):
                     [DatespecExpr([(name, "3-5") for name in self.part_list])],
                 ),
             ).get_reports(),
-            [],
+            [] + self.deprecation_reports,
         )
 
     def test_bad_value(self):
@@ -562,7 +592,8 @@ class DatespecExpression(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
-            ],
+            ]
+            + self.deprecation_reports,
         )
 
     def test_bad_name(self):
