@@ -1,15 +1,41 @@
 from textwrap import dedent
-from unittest import mock, TestCase
-
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import get_test_resource as rc
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs import settings
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import resource
 
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import get_test_resource as rc
+
+
+def _node_fixture(name, node_id):
+    return f'<node id="{node_id}" uname="{name}"/>'
+
+
+def _node_list_fixture(nodes):
+    return "\n".join(
+        _node_fixture(node_name, node_id)
+        for node_id, node_name in enumerate(nodes)
+    )
+
+
+def _nodes_section_fixture(content):
+    return f"""
+    <nodes>
+    {content}
+    </nodes>
+    """
+
+
+nodes_section = _nodes_section_fixture(
+    _node_list_fixture(["node", "node1", "node2"])
+)
 resources_primitive = """
     <resources>
         <primitive id="A" />
@@ -39,8 +65,6 @@ def _action_kwargs(kwargs):
 
 
 class MoveBanClearBaseMixin:
-    # pylint does not and can not know setUp is a method of TestCase
-    # pylint: disable=invalid-name
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
 
@@ -69,7 +93,7 @@ class MoveBanClearBaseMixin:
                 fixture.error(
                     self.report_code_bad_master,
                     resource_id="A",
-                    promotable_id=None,
+                    promotable_id="",
                 ),
             ]
         )
@@ -128,8 +152,24 @@ class MoveBanBaseMixin(MoveBanClearBaseMixin):
             expected_in_processor=False,
         )
 
+    def test_node_not_found(self):
+        self.config.runner.cib.load(resources=resources_primitive)
+        node = "node"
+        self.env_assist.assert_raise_library_error(
+            lambda: self.lib_action(self.env_assist.get_env(), "A", node)
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    report_codes.NODE_NOT_FOUND, node=node, searched_types=[]
+                )
+            ]
+        )
+
     def test_all_options(self):
-        self.config.runner.cib.load(resources=resources_promotable)
+        self.config.runner.cib.load(
+            resources=resources_promotable, nodes=nodes_section
+        )
         self.config_pcmk_action(
             resource="A-clone",
             master=True,
@@ -154,6 +194,25 @@ class MoveBanBaseMixin(MoveBanClearBaseMixin):
             ]
         )
 
+    def assert_multiple_instance(self, stderr, report_code):
+        self.config.runner.cib.load(
+            resources=resources_primitive, nodes=nodes_section
+        )
+        self.config_pcmk_action(resource="A", stderr=stderr, returncode=1)
+        self.env_assist.assert_raise_library_error(
+            lambda: self.lib_action(self.env_assist.get_env(), "A"),
+            [
+                fixture.error(report_code, resource_id="A"),
+            ],
+            expected_in_processor=False,
+        )
+
+    def test_multiple_instance_1(self):
+        self.assert_multiple_instance(
+            "Resource 'A' not moved: active in 2 locations.",
+            self.report_code_multiple_instances,
+        )
+
 
 class MoveMixin:
     lib_action = staticmethod(resource.move)
@@ -165,13 +224,43 @@ class MoveMixin:
     report_code_resource_stopped = (
         report_codes.CANNOT_MOVE_RESOURCE_STOPPED_NO_NODE_SPECIFIED
     )
+    report_code_multiple_instances = (
+        report_codes.CANNOT_MOVE_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED
+    )
 
     def config_pcmk_action(self, *args, **kwargs):
         self.config.runner.pcmk.resource_move(*args, **_action_kwargs(kwargs))
 
 
 class Move(MoveMixin, MoveBanBaseMixin, TestCase):
-    pass
+    def test_resource_may_or_may_not_move(self):
+        self.config.runner.cib.load(
+            resources=resources_primitive, nodes=nodes_section
+        )
+        self.config_pcmk_action(
+            resource="A", node="node1", stdout="", stderr=""
+        )
+        self.lib_action(self.env_assist.get_env(), "A", node="node1")
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    report_codes.RESOURCE_MAY_OR_MAY_NOT_MOVE,
+                    resource_id="A",
+                ),
+                fixture.info(
+                    self.report_code_pcmk_success,
+                    resource_id="A",
+                    stdout="",
+                    stderr="",
+                ),
+            ]
+        )
+
+    def test_multiple_instance_2(self):
+        self.assert_multiple_instance(
+            "Error performing operation: Multiple items match request",
+            report_codes.CANNOT_MOVE_RESOURCE_MULTIPLE_INSTANCES,
+        )
 
 
 class BanMixin:
@@ -184,6 +273,9 @@ class BanMixin:
     report_code_resource_stopped = (
         report_codes.CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED
     )
+    report_code_multiple_instances = (
+        report_codes.CANNOT_BAN_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED
+    )
 
     def config_pcmk_action(self, *args, **kwargs):
         self.config.runner.pcmk.resource_ban(*args, **_action_kwargs(kwargs))
@@ -241,7 +333,6 @@ class UnmoveUnban(UnmoveUnbanMixin, MoveBanClearBaseMixin, TestCase):
         self.env_assist.assert_reports(
             [
                 fixture.error(
-                    # pylint: disable=line-too-long
                     report_codes.RESOURCE_UNMOVE_UNBAN_PCMK_EXPIRED_NOT_SUPPORTED
                 ),
             ]
@@ -269,12 +360,13 @@ class MoveBanWaitMixin:
              </resource>
         </resources>
     """
-    # pylint does not and can not know setUp is a method of TestCase
-    # pylint: disable=invalid-name
+
     def setUp(self):
         self.timeout = 10
         self.env_assist, self.config = get_env_tools(self)
-        self.config.runner.cib.load(resources=resources_primitive)
+        self.config.runner.cib.load(
+            resources=resources_primitive, nodes=nodes_section
+        )
 
     @mock.patch.object(
         settings,
