@@ -30,7 +30,7 @@ class BundleCreateCommon(
         self.temp_cib = get_tmp_file("tier1_bundle_create")
         write_file_to_tmpfile(self.empty_cib, self.temp_cib)
         self.pcs_runner = PcsRunner(self.temp_cib.name)
-        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
+        self.pcs_runner.mock_settings = get_mock_settings()
 
     def tearDown(self):
         self.temp_cib.close()
@@ -182,6 +182,7 @@ class BundleCreate(BundleCreateCommon):
             """,
             stderr_full=(
                 "Deprecation Warning: container option 'masters' is deprecated and "
+                "might be removed in a future release, therefore it "
                 "should not be used, use 'promoted-max' instead\n"
             ),
         )
@@ -195,6 +196,7 @@ class BundleCreate(BundleCreateCommon):
             "Error: Only one of container options 'masters' and "
             "'promoted-max' can be used\n"
             "Deprecation Warning: container option 'masters' is deprecated and "
+            "might be removed in a future release, therefore it "
             "should not be used, use 'promoted-max' instead\n"
             + ERRORS_HAVE_OCCURRED,
         )
@@ -499,6 +501,7 @@ class BundleUpdate(BundleCreateCommon):
             """,
             stderr_full=(
                 "Deprecation Warning: container option 'masters' is deprecated and "
+                "might be removed in a future release, therefore it "
                 "should not be used, use 'promoted-max' instead\n"
             ),
         )
@@ -509,6 +512,7 @@ class BundleUpdate(BundleCreateCommon):
             "resource bundle update B container masters=2".split(),
             stderr_full=(
                 "Deprecation Warning: container option 'masters' is deprecated and "
+                "might be removed in a future release, therefore it "
                 "should not be used, use 'promoted-max' instead\n"
             ),
         )
@@ -536,8 +540,9 @@ class BundleUpdate(BundleCreateCommon):
         )
         self.assert_pcs_fail(
             "resource bundle update B container masters=2".split(),
-            "Deprecation Warning: container option 'masters' is deprecated "
-            "and should not be used, use 'promoted-max' instead\n"
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "might be removed in a future release, therefore it "
+            "should not be used, use 'promoted-max' instead\n"
             "Error: Cannot set container option 'masters' because container "
             "option 'promoted-max' is already set\n" + ERRORS_HAVE_OCCURRED,
         )
@@ -558,6 +563,7 @@ class BundleUpdate(BundleCreateCommon):
             """,
             stderr_full=(
                 "Deprecation Warning: container option 'masters' is deprecated and "
+                "might be removed in a future release, therefore it "
                 "should not be used, use 'promoted-max' instead\n"
             ),
         )
@@ -568,6 +574,7 @@ class BundleUpdate(BundleCreateCommon):
             "resource bundle update B container masters=2".split(),
             stderr_full=(
                 "Deprecation Warning: container option 'masters' is deprecated and "
+                "might be removed in a future release, therefore it "
                 "should not be used, use 'promoted-max' instead\n"
             ),
         )
@@ -584,6 +591,7 @@ class BundleUpdate(BundleCreateCommon):
             "resource bundle update B container masters=2".split(),
             stderr_full=(
                 "Deprecation Warning: container option 'masters' is deprecated and "
+                "might be removed in a future release, therefore it "
                 "should not be used, use 'promoted-max' instead\n"
             ),
         )
@@ -800,7 +808,7 @@ class BundleShow(TestCase, AssertPcsMixin):
             ).split()
         )
         self.assert_pcs_success(
-            "resource create A ocf:pacemaker:Dummy bundle B1 --no-default-ops".split()
+            "resource create A ocf:pcsmock:minimal bundle B1 --no-default-ops".split()
         )
         self.assert_pcs_success(
             "resource config B1".split(),
@@ -809,7 +817,7 @@ class BundleShow(TestCase, AssertPcsMixin):
                 Bundle: B1
                   Docker: image=pcs:test
                   Network: control-port=1234
-                  Resource: A (class=ocf provider=pacemaker type=Dummy)
+                  Resource: A (class=ocf provider=pcsmock type=minimal)
                     Operations:
                       monitor: A-monitor-interval-10s
                         interval=10s timeout=20s
@@ -853,7 +861,7 @@ class BundleShow(TestCase, AssertPcsMixin):
             ]
         )
         self.assert_pcs_success(
-            "resource create A ocf:pacemaker:Dummy bundle B1 --no-default-ops".split()
+            "resource create A ocf:pcsmock:minimal bundle B1 --no-default-ops".split()
         )
         self.assert_pcs_success(
             "resource config B1".split(),
@@ -871,7 +879,7 @@ class BundleShow(TestCase, AssertPcsMixin):
                   Meta Attributes: B1-meta_attributes
                     is-managed=false
                     target-role=Stopped
-                  Resource: A (class=ocf provider=pacemaker type=Dummy)
+                  Resource: A (class=ocf provider=pcsmock type=minimal)
                     Operations:
                       monitor: A-monitor-interval-10s
                         interval=10s timeout=20s
