@@ -592,9 +592,9 @@ class EnableAuthfile(BoothMixin, TestCase):
     def setUp(self):
         super().setUp()
         self.pcs_runner.cib_file = None
-        self.pcs_runner.mock_settings[
-            "booth_enable_authfile_set_enabled"
-        ] = str(True)
+        self.pcs_runner.mock_settings["booth_enable_authfile_set_enabled"] = (
+            str(True)
+        )
         self.ensure_booth_config_not_exists()
 
     def test_not_enabled(self):
@@ -640,9 +640,9 @@ class CleanEnableAuthfile(BoothMixin, TestCase):
         super().setUp()
         self.pcs_runner.cib_file = None
         self.ensure_booth_config_not_exists()
-        self.pcs_runner.mock_settings[
-            "booth_enable_authfile_unset_enabled"
-        ] = str(True)
+        self.pcs_runner.mock_settings["booth_enable_authfile_unset_enabled"] = (
+            str(True)
+        )
 
     def test_not_set(self):
         with open(self.booth_cfg_path, "w") as config_file:
@@ -699,3 +699,37 @@ class CleanEnableAuthfile(BoothMixin, TestCase):
                 ),
                 config_file.read(),
             )
+
+
+class BoothTicketOperationBase(BoothMixinNoFiles):
+    command = ""
+
+    def test_not_enough_args(self):
+        self.assert_pcs_fail(
+            ["booth", "ticket", self.command],
+            stderr_start=(
+                "\nUsage: pcs booth <command>\n"
+                f"    ticket {self.command} <ticket>\n"
+            ),
+        )
+
+    def test_too_many_args(self):
+        self.assert_pcs_fail(
+            ["booth", "ticket", self.command, "a", "b"],
+            stderr_start=(
+                "\nUsage: pcs booth <command>\n"
+                f"    ticket {self.command} <ticket>\n"
+            ),
+        )
+
+
+class TicketCleanup(BoothTicketOperationBase, TestCase):
+    command = "cleanup"
+
+
+class TicketUnstandby(BoothTicketOperationBase, TestCase):
+    command = "unstandby"
+
+
+class TicketStandby(BoothTicketOperationBase, TestCase):
+    command = "standby"
