@@ -1,4 +1,5 @@
 import os
+from typing import Optional
 
 from pcs import settings
 
@@ -158,6 +159,7 @@ class PcmkShortcuts:
 
     def load_state(
         self,
+        *,
         name="runner.pcmk.load_state",
         filename="crm_mon.minimal.xml",
         resources=None,
@@ -216,6 +218,7 @@ class PcmkShortcuts:
 
     def load_state_plaintext(
         self,
+        *,
         name="runner.pcmk.load_state_plaintext",
         inactive=True,
         verbose=False,
@@ -354,6 +357,7 @@ class PcmkShortcuts:
 
     def load_agent(
         self,
+        *,
         name="runner.pcmk.load_agent",
         agent_name="ocf:heartbeat:Dummy",
         agent_filename=None,
@@ -375,23 +379,12 @@ class PcmkShortcuts:
             placed
         dict env -- CommandRunner environment variables
         """
-        if env:
-            env = dict(env)
-        else:
-            env = {}
-        env["PATH"] = ":".join(
-            [
-                settings.fence_agent_execs,
-                "/bin",
-                "/usr/bin",
-            ]
-        )
-
-        if agent_filename:
-            agent_metadata_filename = agent_filename
-        elif agent_name in AGENT_FILENAME_MAP:
-            agent_metadata_filename = AGENT_FILENAME_MAP[agent_name]
-        elif not stdout and not agent_is_missing:
+        if (
+            not agent_is_missing
+            and not stdout
+            and not agent_filename
+            and agent_name not in AGENT_FILENAME_MAP
+        ):
             raise AssertionError(
                 (
                     "Filename with metadata of agent '{0}' not specified.\n"
@@ -406,6 +399,18 @@ class PcmkShortcuts:
                 ).format(agent_name, os.path.realpath(__file__), rc(""))
             )
 
+        if env:
+            env = dict(env)
+        else:
+            env = {}
+        env["PATH"] = ":".join(
+            [
+                settings.fence_agent_execs,
+                "/bin",
+                "/usr/bin",
+            ]
+        )
+
         if agent_is_missing:
             if stderr is None:
                 stderr = (
@@ -428,6 +433,10 @@ class PcmkShortcuts:
             return
 
         if not stdout:
+            if agent_filename:
+                agent_metadata_filename = agent_filename
+            else:
+                agent_metadata_filename = AGENT_FILENAME_MAP[agent_name]
             with open(rc(agent_metadata_filename)) as a_file:
                 stdout = a_file.read()
         self.__calls.place(
@@ -527,8 +536,47 @@ class PcmkShortcuts:
             instead=instead,
         )
 
+    def resource_restart(
+        self,
+        resource: str,
+        node: Optional[str] = None,
+        timeout: Optional[str] = None,
+        stdout: str = "",
+        stderr: str = "",
+        returncode: int = 0,
+        name: str = "runner.pcmk.restart",
+    ):
+        """
+        Create a call for crm_resource --restart
+
+        name -- the key of this call
+        resource -- the id of a resource to be restarted
+        node -- the name of the node where the resource should be restarted
+        timeout -- how long to wait for the resource to restart
+        stdout -- crm_resource's stdout
+        stderr -- crm_resource's stderr
+        returncode -- crm_resource's returncode
+        """
+        cmd = ["crm_resource", "--restart"]
+        if resource:
+            cmd.extend(["--resource", resource])
+        if node:
+            cmd.extend(["--node", node])
+        if timeout:
+            cmd.extend(["--timeout", timeout])
+        self.__calls.place(
+            name,
+            RunnerCall(
+                cmd,
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+            ),
+        )
+
     def resource_cleanup(
         self,
+        *,
         name="runner.pcmk.cleanup",
         instead=None,
         before=None,
@@ -575,6 +623,7 @@ class PcmkShortcuts:
 
     def resource_refresh(
         self,
+        *,
         name="runner.pcmk.refresh",
         instead=None,
         before=None,
@@ -621,6 +670,7 @@ class PcmkShortcuts:
 
     def resource_move(
         self,
+        *,
         name="runner.pcmk.resource_move",
         instead=None,
         before=None,
@@ -659,6 +709,7 @@ class PcmkShortcuts:
 
     def resource_ban(
         self,
+        *,
         name="runner.pcmk.resource_ban",
         instead=None,
         before=None,
@@ -695,6 +746,7 @@ class PcmkShortcuts:
 
     def resource_clear(
         self,
+        *,
         name="runner.pcmk.resource_clear",
         instead=None,
         before=None,
@@ -735,6 +787,7 @@ class PcmkShortcuts:
         self,
         name,
         action,
+        *,
         instead=None,
         before=None,
         resource=None,
@@ -933,6 +986,7 @@ class PcmkShortcuts:
         self,
         new_cib_filepath,
         transitions_filepath,
+        *,
         cib_xml=None,
         cib_modifiers=None,
         cib_load_name="runner.cib.load",
@@ -1025,6 +1079,7 @@ class PcmkShortcuts:
         standard="ocf",
         provider="heartbeat",
         agent_type="Dummy",
+        *,
         returncode=0,
         output=None,
         stdout="",
@@ -1078,6 +1133,7 @@ class PcmkShortcuts:
         self,
         attributes,
         agent,
+        *,
         returncode=0,
         output=None,
         stdout="",
@@ -1115,3 +1171,67 @@ class PcmkShortcuts:
             RunnerCall(cmd, stdout=stdout, returncode=returncode, env=env),
             instead=instead,
         )
+
+    def ticket_unstandby(
+        self,
+        ticket_name: str,
+        stderr="",
+        returncode=0,
+        name="runner.pcmk.ticket_unstandby",
+    ) -> None:
+        self.__calls.place(
+            name,
+            RunnerCall(
+                [
+                    settings.crm_ticket_exec,
+                    "--activate",
+                    "--ticket",
+                    ticket_name,
+                ],
+                stderr=stderr,
+                returncode=returncode,
+            ),
+        )
+
+    def ticket_standby(
+        self,
+        ticket_name: str,
+        stderr="",
+        returncode=0,
+        name="runner.pcmk.ticket_standby",
+    ) -> None:
+        self.__calls.place(
+            name,
+            RunnerCall(
+                [
+                    settings.crm_ticket_exec,
+                    "--standby",
+                    "--ticket",
+                    ticket_name,
+                ],
+                stderr=stderr,
+                returncode=returncode,
+            ),
+        )
+
+    def ticket_cleanup(
+        self,
+        ticket_name: str,
+        stderr="",
+        returncode=0,
+        name="runner.pcmk.ticket_cleanup",
+    ) -> None:
+        self.__calls.place(
+            name,
+            RunnerCall(
+                [
+                    settings.crm_ticket_exec,
+                    "--cleanup",
+                    "--force",
+                    "--ticket",
+                    ticket_name,
+                ],
+                stderr=stderr,
+                returncode=returncode,
+            ),
+        )
